-- DROP TABLE IF EXISTS `sys_workflow`;
CREATE TABLE IF NOT EXISTS `sys_workflow` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `parent` varchar(30) NOT NULL, 
  `child` varchar(30) NOT NULL, 
  `type` varchar(10) NOT NULL DEFAULT 'flow',
  `app` varchar(20) NOT NULL,
  `position` varchar(30) NOT NULL,
  `module` varchar(30) NOT NULL,
  `table` varchar(50) NOT NULL,
  `name` varchar(30) NOT NULL,
  `flowchart` text NOT NULL,
  `js` text NOT NULL,
  `css` text NOT NULL,
  `order` smallint(5) unsigned NOT NULL,
  `buildin` tinyint(1) unsigned NOT NULL,
  `administrator` text NOT NULL,
  `desc` text NOT NULL,
  `version` varchar(10) NOT NULL DEFAULT '1.0',
  `status` varchar(10) NOT NULL DEFAULT 'wait',
  `createdBy` varchar(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  `editedBy` varchar(30) NOT NULL,
  `editedDate` datetime NOT NULL,
  PRIMARY KEY `id` (`id`),
  KEY `type` (`type`),
  KEY `app` (`app`),
  KEY `module` (`module`),
  KEY `order` (`order`),
  UNIQUE KEY `unique` (`app`, `module`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `sys_workflowaction`;
CREATE TABLE IF NOT EXISTS `sys_workflowaction` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `module` varchar(30) NOT NULL,
  `action` varchar(50) NOT NULL,
  `name` varchar(50) NOT NULL,
  `type` enum('single', 'batch') NOT NULL DEFAULT 'single',
  `batchMode` enum('same', 'different') NOT NULL DEFAULT 'different',
  `extensionType` varchar(10) NOT NULL DEFAULT 'override' COMMENT 'none | extend | override',
  `open` varchar(20) NOT NULL,
  `position` enum('menu', 'browseandview', 'browse', 'view') NOT NULL DEFAULT 'browseandview',
  `layout` char(20) NOT NULL,
  `show` enum('dropdownlist', 'direct') NOT NULL DEFAULT 'dropdownlist',
  `order` smallint(5) unsigned NOT NULL,
  `buildin` tinyint(1) unsigned NOT NULL,
  `virtual` tinyint(1) unsigned NOT NULL,
  `conditions` text NOT NULL,
  `verifications` text NOT NULL,
  `hooks` text NOT NULL,
  `linkages` text NOT NULL,
  `js` text NOT NULL,
  `css` text NOT NULL,
  `toList` char(255) NOT NULL,
  `blocks` text NOT NULL,
  `desc` text NOT NULL,
  `status` varchar(10) NOT NULL DEFAULT 'enable',
  `createdBy` varchar(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  `editedBy` varchar(30) NOT NULL,
  `editedDate` datetime NOT NULL,
  PRIMARY KEY `id` (`id`),
  KEY `module` (`module`),
  KEY `action` (`action`),
  KEY `order` (`order`),
  UNIQUE KEY `unique` (`module`, `action`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `sys_workflowdatasource`;
CREATE TABLE IF NOT EXISTS `sys_workflowdatasource` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `type` enum('system', 'sql', 'func', 'option', 'lang', 'category') NOT NULL DEFAULT 'option',
  `name` varchar(30) NOT NULL,
  `datasource` text NOT NULL, 
  `view` varchar(20) NOT NULL,
  `keyField` varchar(50) NOT NULL,
  `valueField` varchar(50) NOT NULL,
  `createdBy` char(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  `editedBy` char(30) NOT NULL,
  `editedDate` datetime NOT NULL,
  PRIMARY KEY (`id`),
  KEY `type` (`type`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `sys_workflowfield`;
CREATE TABLE IF NOT EXISTS `sys_workflowfield` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `module` varchar(30) NOT NULL,
  `field`  varchar(50) NOT NULL,
  `type` varchar(20) NOT NULL DEFAULT 'varchar',
  `length` varchar(10) NOT NULL,
  `name` varchar(50) NOT NULL,
  `control` varchar(20) NOT NULL,
  `expression` text NOT NULL,
  `options` text NOT NULL,
  `default` varchar(100) NOT NULL,
  `rules` varchar(255) NOT NULL,
  `placeholder` varchar(100) NOT NULL,
  `order` smallint(5) unsigned NOT NULL,
  `searchOrder` smallint(5) unsigned NOT NULL DEFAULT '0', 
  `exportOrder` smallint(5) unsigned NOT NULL DEFAULT '0',
  `canExport` enum('0', '1') NOT NULL DEFAULT '0',
  `canSearch` enum('0', '1') NOT NULL DEFAULT '0',
  `isValue` enum('0', '1') NOT NULL DEFAULT '0',
  `readonly` enum('0', '1') NOT NULL DEFAULT '0',
  `buildin` tinyint(1) unsigned NOT NULL,
  `desc` text NOT NULL,
  `createdBy` varchar(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  `editedBy` varchar(30) NOT NULL,
  `editedDate` datetime NOT NULL,
  PRIMARY KEY `id` (`id`),
  KEY `module` (`module`),
  KEY `field` (`field`),
  KEY `order` (`order`),
  UNIQUE KEY `unique` (`module`, `field`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `sys_workflowlayout`;
CREATE TABLE IF NOT EXISTS `sys_workflowlayout` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `module` varchar(30) NOT NULL,
  `action` varchar(50) NOT NULL,
  `field`  varchar(50) NOT NULL,
  `order` smallint(5) unsigned NOT NULL,
  `width` smallint(5) NOT NULL,
  `position` text NOT NULL,
  `readonly` enum('0', '1') NOT NULL DEFAULT '0',
  `mobileShow` enum('0', '1') NOT NULL DEFAULT '1',
  `summary` varchar(20) NOT NULL,
  `defaultValue` text NOT NULL,
  `layoutRules` varchar(255) NOT NULL,
  PRIMARY KEY `id` (`id`),
  KEY `module` (`module`),
  KEY `action` (`action`),
  KEY `order` (`order`),
  UNIQUE KEY `unique` (`module`, `action`, `field`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `sys_workflowlabel`;
CREATE TABLE IF NOT EXISTS `sys_workflowlabel` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `module` varchar(30) NOT NULL,
  `code` varchar(30) NOT NULL,
  `label` varchar(255) NOT NULL,
  `params` text NOT NULL,
  `orderBy` text NOT NULL,
  `order` tinyint(3) NOT NULL,
  `buildin` tinyint(1) unsigned NOT NULL,
  `createdBy` char(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  `editedBy` char(30) NOT NULL,
  `editedDate` datetime NOT NULL,
  PRIMARY KEY (`id`),
  KEY `module` (`module`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `sys_workflowlinkdata`;
CREATE TABLE IF NOT EXISTS `sys_workflowlinkdata` (
  `objectType` varchar(30) NOT NULL,
  `objectID` mediumint(8) unsigned NOT NULL,
  `linkedType` varchar(30) NOT NULL,
  `linkedID` mediumint(8) unsigned NOT NULL,
  `createdBy` varchar(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  UNIQUE KEY `unique` (`objectType`, `objectID`, `linkedType`, `linkedID`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `sys_workflowrelation`;
CREATE TABLE IF NOT EXISTS `sys_workflowrelation` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `prev` varchar(30) NOT NULL, 
  `next` varchar(30) NOT NULL,
  `field` varchar(50) NOT NULL,
  `actions` varchar(20) NOT NULL,
  `createdBy` char(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `sys_workflowrelationlayout`;
CREATE TABLE IF NOT EXISTS `sys_workflowrelationlayout` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `prev` varchar(30) NOT NULL,
  `next` varchar(30) NOT NULL,
  `action` varchar(50) NOT NULL,
  `field` varchar(50) NOT NULL,
  `order` smallint(5) unsigned NOT NULL,
  PRIMARY KEY `id` (`id`),
  KEY `prev` (`prev`),
  KEY `next` (`next`),
  KEY `action` (`action`),
  KEY `order` (`order`),
  UNIQUE KEY `unique` (`prev`, `next`, `action`, `field`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `sys_workflowrule`;
CREATE TABLE IF NOT EXISTS `sys_workflowrule` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `type` enum('system', 'regex', 'func') NOT NULL DEFAULT 'regex',
  `name` varchar(30) NOT NULL,
  `rule` text NOT NULL, 
  `createdBy` char(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  `editedBy` char(30) NOT NULL,
  `editedDate` datetime NOT NULL,
  PRIMARY KEY (`id`),
  KEY `type` (`type`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `sys_workflowsql`;
CREATE TABLE IF NOT EXISTS `sys_workflowsql` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `module` varchar(30) NOT NULL,
  `field` varchar(50) NOT NULL,
  `action` varchar(50) NOT NULL,
  `sql` text NOT NULL,
  `vars` text NOT NULL,
  `createdBy` varchar(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  `editedBy` varchar(30) NOT NULL,
  `editedDate` datetime NOT NULL,
  PRIMARY KEY `id` (`id`),
  KEY `module` (`module`),
  KEY `field` (`field`),
  KEY `action` (`action`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `sys_workflowversion`;
CREATE TABLE IF NOT EXISTS `sys_workflowversion` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `module` varchar(30) NOT NULL,
  `version` varchar(10) NOT NULL,
  `fields` text NOT NULL,
  `actions` text NOT NULL,
  `layouts` text NOT NULL,
  `sqls` text NOT NULL,
  `labels` text NOT NULL,
  `table` text NOT NULL,
  `datas` text NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `moduleversion` (`module`, `version`),
  KEY `module` (`module`),
  KEY `version` (`version`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `sys_workflowreport`;
CREATE TABLE IF NOT EXISTS `sys_workflowreport` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `module` varchar(30) NOT NULL COMMENT 'module name',
  `name` varchar(100) NOT NULL COMMENT 'report name',
  `type` enum('pie', 'line', 'bar') NOT NULL DEFAULT 'pie' COMMENT 'report type',
  `countType` enum('sum', 'count') NOT NULL DEFAULT 'sum' COMMENT 'report count method',
  `displayType` enum('value', 'percent') NOT NULL DEFAULT 'value' COMMENT 'report display method',
  `dimension` varchar(130) NOT NULL COMMENT 'dimension field code of sys_workflowfield',
  `fields` text NOT NULL COMMENT 'count fileds code of sys_workflowfield,use comma split',
  `order` smallint(5) unsigned NOT NULL DEFAULT '0',
  `createdBy` varchar(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  PRIMARY KEY `id` (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

ALTER TABLE `sys_action` CHANGE `action` `action` varchar(80) NOT NULL DEFAULT '';
ALTER TABLE `sys_action` CHANGE `extra` `extra` text;
ALTER TABLE `sys_file`   CHANGE `objectType` `objectType` char(30) NOT NULL;

INSERT INTO `sys_workflow` VALUES (1,'','','flow','flow','','meetingroom','flow_meetingroom','会议室','[{\"position\":{\"left\":810,\"top\":20},\"id\":\"start\",\"type\":\"start\",\"text\":\"\\u5f00\\u59cb\",\"readonly\":true,\"codeReadonly\":true},{\"position\":{\"left\":800,\"top\":120},\"id\":\"create\",\"type\":\"process\",\"text\":\"\\u65b0\\u5efa\",\"code\":\"create\",\"codeReadonly\":true},{\"position\":{\"left\":800,\"top\":220},\"id\":\"edit\",\"type\":\"process\",\"text\":\"\\u7f16\\u8f91\",\"code\":\"edit\",\"codeReadonly\":true},{\"position\":{\"left\":810,\"top\":400},\"id\":\"stop\",\"type\":\"stop\",\"text\":\"\\u7ed3\\u675f\",\"readonly\":true,\"codeReadonly\":true},{\"from\":\"start\",\"to\":\"create\",\"id\":\"start-add\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"edit\",\"id\":\"create-edit\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"edit\",\"to\":\"stop\",\"fromPort\":\"bottom2\",\"toPort\":\"top2\",\"id\":\"hiusgy4lmtk0\",\"type\":\"relation\",\"text\":\"\"}]','','',0,0,'{\"users\":[],\"groups\":[]}','','1.0','normal','admin','2020-10-29 15:00:44','','0000-00-00 00:00:00'),(2,'','','flow','flow','','meetingroombooking','flow_meetingroombooking','会议室预订','[{\"position\":{\"left\":810,\"top\":20},\"id\":\"start\",\"type\":\"start\",\"text\":\"\\u5f00\\u59cb\",\"readonly\":true,\"codeReadonly\":true},{\"position\":{\"left\":800,\"top\":120},\"id\":\"create\",\"type\":\"process\",\"text\":\"\\u65b0\\u5efa\",\"code\":\"create\",\"codeReadonly\":true},{\"position\":{\"left\":800,\"top\":220},\"id\":\"edit\",\"type\":\"process\",\"text\":\"\\u7f16\\u8f91\",\"code\":\"edit\",\"codeReadonly\":true},{\"position\":{\"left\":810,\"top\":380},\"id\":\"stop\",\"type\":\"stop\",\"text\":\"\\u7ed3\\u675f\",\"readonly\":true,\"codeReadonly\":true},{\"from\":\"start\",\"to\":\"create\",\"id\":\"start-add\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"edit\",\"id\":\"create-edit\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"edit\",\"to\":\"stop\",\"fromPort\":\"bottom2\",\"id\":\"hiut8bpp2vc0\",\"type\":\"relation\",\"text\":\"\"}]','','',0,0,'{\"users\":[],\"groups\":[]}','','1.0','normal','admin','2020-10-29 15:00:44','','0000-00-00 00:00:00'),(3,'','','flow','flow','','stamp','flow_stamp','印章申请','[{\"position\":{\"left\":740,\"top\":20},\"id\":\"start\",\"type\":\"start\",\"text\":\"\\u5f00\\u59cb\",\"readonly\":true,\"codeReadonly\":true},{\"position\":{\"left\":730,\"top\":120},\"id\":\"create\",\"type\":\"process\",\"text\":\"\\u65b0\\u5efa\",\"code\":\"create\",\"codeReadonly\":true},{\"position\":{\"left\":545,\"top\":120},\"id\":\"edit\",\"type\":\"process\",\"text\":\"\\u7f16\\u8f91\",\"code\":\"edit\",\"codeReadonly\":true},{\"position\":{\"left\":740,\"top\":515},\"id\":\"stop\",\"type\":\"stop\",\"text\":\"\\u7ed3\\u675f\",\"readonly\":true,\"codeReadonly\":true},{\"position\":{\"left\":885,\"top\":120},\"id\":\"fho6kaava340\",\"type\":\"process\",\"text\":\"\\u64a4\\u9500\",\"from\":\"create.right1\",\"code\":\"revoke\",\"codeReadonly\":true},{\"position\":{\"left\":1050,\"top\":120},\"id\":\"fho9am8hv2w0\",\"type\":\"process\",\"text\":\"\\u63d0\\u4ea4\",\"from\":\"fho6kaava340.right1\",\"code\":\"submit\",\"codeReadonly\":true},{\"position\":{\"left\":730,\"top\":395},\"id\":\"fjmdz0609aw0\",\"type\":\"process\",\"text\":\"\\u901a\\u8fc7\",\"code\":\"pass\",\"codeReadonly\":true},{\"position\":{\"left\":745,\"top\":265},\"id\":\"hix3o38qhog0\",\"type\":\"result\",\"text\":\"\\u5f85\\u5ba1\\u6838\",\"toggle\":\"tooltip\",\"placement\":\"right\",\"codeReadonly\":true},{\"position\":{\"left\":545,\"top\":280},\"id\":\"hiximnlqn6o0\",\"type\":\"process\",\"text\":\"\\u62d2\\u7edd\",\"code\":\"reject\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"fho6kaava340\",\"fromPort\":\"right1\",\"id\":\"hiy6btfkn5k0\",\"type\":\"relation\",\"text\":\"\"},{\"from\":\"fho6kaava340\",\"to\":\"fho9am8hv2w0\",\"fromPort\":\"right1\",\"id\":\"hiy6btif0m80\",\"type\":\"relation\",\"text\":\"\"},{\"from\":\"create\",\"to\":\"fho6kaava340\",\"fromPort\":\"right1\",\"id\":\"hixm6kg2k4g0\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"fho6kaava340\",\"to\":\"fho9am8hv2w0\",\"fromPort\":\"right1\",\"id\":\"hixm6kg5vnk0\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"fho6kaava340\",\"fromPort\":\"right1\",\"id\":\"hixkd53h3400\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"fho6kaava340\",\"to\":\"fho9am8hv2w0\",\"fromPort\":\"right1\",\"id\":\"hixkd55xkww0\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"fho6kaava340\",\"fromPort\":\"right1\",\"id\":\"hixifii2es80\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"fho6kaava340\",\"to\":\"fho9am8hv2w0\",\"fromPort\":\"right1\",\"id\":\"hixifikopsg0\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"fho6kaava340\",\"fromPort\":\"right1\",\"id\":\"hixhtevji800\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"fho6kaava340\",\"to\":\"fho9am8hv2w0\",\"fromPort\":\"right1\",\"id\":\"hixhtewlrg80\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"fho6kaava340\",\"fromPort\":\"right1\",\"id\":\"hiwyibplz4g0\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"fho6kaava340\",\"to\":\"fho9am8hv2w0\",\"fromPort\":\"right1\",\"id\":\"hiwyibqlf480\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"fho6kaava340\",\"fromPort\":\"right1\",\"id\":\"fjmk4lxqs6g0\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"fho6kaava340\",\"to\":\"fho9am8hv2w0\",\"fromPort\":\"right1\",\"id\":\"fjmk4lygvco0\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"fho6kaava340\",\"fromPort\":\"right1\",\"id\":\"fjmcsesojs00\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"fho6kaava340\",\"to\":\"fho9am8hv2w0\",\"fromPort\":\"right1\",\"id\":\"fjmcset5h280\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"fho6kaava340\",\"fromPort\":\"right1\",\"id\":\"fhonbi2cek00\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"fho6kaava340\",\"to\":\"fho9am8hv2w0\",\"fromPort\":\"right1\",\"id\":\"fhonbi3mt6o0\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"start\",\"to\":\"create\",\"id\":\"start-add\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"fho6kaava340\",\"fromPort\":\"right1\",\"id\":\"fho6kaarsag0\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"fho6kaava340\",\"to\":\"fho9am8hv2w0\",\"fromPort\":\"right1\",\"id\":\"fho9am9598w0\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"edit\",\"fromPort\":\"left1\",\"toPort\":\"right1\",\"id\":\"hix369bkn2g0\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"hix3o38qhog0\",\"fromPort\":\"bottom2\",\"id\":\"hix417smm1c0\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"fjmdz0609aw0\",\"to\":\"stop\",\"fromPort\":\"bottom2\",\"id\":\"hixhlnf8taw0\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"hiximnlqn6o0\",\"to\":\"edit\",\"fromPort\":\"top1\",\"toPort\":\"bottom1\",\"id\":\"hixk4s4n11c0\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"position\":{\"shape\":{\"porX\":0.10190779014308,\"porY\":-6.9388939039072e-18}},\"from\":\"edit\",\"to\":\"hix3o38qhog0\",\"fromPort\":\"bottom2\",\"toPort\":\"top1\",\"id\":\"hixn3oekank0\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"hix3o38qhog0\",\"to\":\"hiximnlqn6o0\",\"fromPort\":\"left1\",\"toPort\":\"right1\",\"id\":\"hixotbrj26g0\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"hix3o38qhog0\",\"to\":\"fjmdz0609aw0\",\"fromPort\":\"bottom1\",\"toPort\":\"top2\",\"id\":\"hixpgn9dj200\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"position\":{\"shape\":{\"porX\":1.6853146853147,\"porY\":1.5460992907801}},\"from\":\"fho9am8hv2w0\",\"to\":\"hix3o38qhog0\",\"fromPort\":\"bottom2\",\"toPort\":\"right1\",\"id\":\"hiy6lv79uw80\",\"type\":\"relation\",\"text\":\"\"}]','','',0,0,'{\"users\":[],\"groups\":[]}','','1.0','normal','admin','2020-10-29 15:00:44','','0000-00-00 00:00:00'),(4,'','','flow','flow','','car','flow_car','车辆信息','[{\"position\":{\"left\":810,\"top\":20},\"id\":\"start\",\"type\":\"start\",\"text\":\"\\u5f00\\u59cb\",\"readonly\":true,\"codeReadonly\":true},{\"position\":{\"left\":800,\"top\":120},\"id\":\"create\",\"type\":\"process\",\"text\":\"\\u65b0\\u5efa\",\"code\":\"create\",\"codeReadonly\":true},{\"position\":{\"left\":800,\"top\":220},\"id\":\"edit\",\"type\":\"process\",\"text\":\"\\u7f16\\u8f91\",\"code\":\"edit\",\"codeReadonly\":true},{\"position\":{\"left\":810,\"top\":360},\"id\":\"stop\",\"type\":\"stop\",\"text\":\"\\u7ed3\\u675f\",\"readonly\":true,\"codeReadonly\":true},{\"from\":\"start\",\"to\":\"create\",\"id\":\"start-add\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"edit\",\"id\":\"create-edit\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"edit\",\"to\":\"stop\",\"fromPort\":\"bottom2\",\"toPort\":\"top2\",\"id\":\"hiuy1o96bqo0\",\"type\":\"relation\",\"text\":\"\"}]','','',0,0,'{\"users\":[],\"groups\":[]}','','1.0','normal','admin','2020-10-29 15:00:44','','0000-00-00 00:00:00'),(5,'','','flow','flow','','carbooking','flow_carbooking','车辆预订','[{\"position\":{\"left\":720,\"top\":20},\"id\":\"start\",\"type\":\"start\",\"text\":\"\\u5f00\\u59cb\",\"readonly\":true,\"codeReadonly\":true},{\"position\":{\"left\":710,\"top\":120},\"id\":\"create\",\"type\":\"process\",\"text\":\"\\u65b0\\u5efa\",\"code\":\"create\",\"codeReadonly\":true},{\"position\":{\"left\":540,\"top\":120},\"id\":\"edit\",\"type\":\"process\",\"text\":\"\\u7f16\\u8f91\",\"code\":\"edit\",\"codeReadonly\":true},{\"position\":{\"left\":890,\"top\":415},\"id\":\"stop\",\"type\":\"stop\",\"text\":\"\\u7ed3\\u675f\",\"readonly\":true,\"codeReadonly\":true},{\"position\":{\"left\":880,\"top\":270},\"id\":\"hiv40m6o1sw0\",\"type\":\"process\",\"text\":\"\\u901a\\u8fc7\",\"code\":\"pass\",\"codeReadonly\":true},{\"position\":{\"left\":540,\"top\":345},\"id\":\"hiv54jihqeo0\",\"type\":\"process\",\"text\":\"\\u62d2\\u7edd\",\"code\":\"reject\",\"codeReadonly\":true},{\"position\":{\"left\":725,\"top\":255},\"id\":\"hiv88ldezeg0\",\"type\":\"result\",\"text\":\"\\u5f85\\u5ba1\\u6838\",\"toggle\":\"tooltip\",\"placement\":\"right\"},{\"from\":\"start\",\"to\":\"create\",\"id\":\"start-add\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"edit\",\"fromPort\":\"left1\",\"toPort\":\"right1\",\"id\":\"hiv44yllvg00\",\"type\":\"relation\",\"text\":\"\"},{\"from\":\"create\",\"to\":\"hiv88ldezeg0\",\"fromPort\":\"bottom2\",\"toPort\":\"top1\",\"id\":\"hiv8ddsc9gw0\",\"type\":\"relation\",\"text\":\"\"},{\"from\":\"hiv88ldezeg0\",\"to\":\"hiv40m6o1sw0\",\"fromPort\":\"right1\",\"toPort\":\"left1\",\"id\":\"hiv8vpdd9uw0\",\"type\":\"relation\",\"text\":\"\"},{\"from\":\"hiv40m6o1sw0\",\"to\":\"stop\",\"fromPort\":\"bottom2\",\"toPort\":\"top2\",\"id\":\"hiv94kr4uko0\",\"type\":\"relation\",\"text\":\"\"},{\"from\":\"hiv54jihqeo0\",\"to\":\"edit\",\"fromPort\":\"top1\",\"toPort\":\"bottom1\",\"id\":\"hivar3wei3s0\",\"type\":\"relation\",\"text\":\"\"},{\"position\":{\"shape\":{\"porX\":1.8793103448276,\"porY\":1.4242424242424}},\"from\":\"hiv88ldezeg0\",\"to\":\"hiv54jihqeo0\",\"fromPort\":\"bottom1\",\"toPort\":\"right1\",\"id\":\"hivcgxtzo5c0\",\"type\":\"relation\",\"text\":\"\"},{\"position\":{\"shape\":{\"porX\":-1.8198198198198,\"porY\":1.6335877862595}},\"from\":\"edit\",\"to\":\"hiv88ldezeg0\",\"fromPort\":\"bottom3\",\"toPort\":\"left1\",\"id\":\"hivd0dqi8k80\",\"type\":\"relation\",\"text\":\"\"}]','','',0,0,'{\"users\":[],\"groups\":[]}','','1.0','normal','admin','2020-10-29 15:00:44','','0000-00-00 00:00:00'),(6,'','','flow','flow','','collect','flow_collect','请款','[{\"position\":{\"left\":810,\"top\":20},\"id\":\"start\",\"type\":\"start\",\"text\":\"\\u5f00\\u59cb\",\"readonly\":true,\"codeReadonly\":true},{\"position\":{\"left\":800,\"top\":120},\"id\":\"create\",\"type\":\"process\",\"text\":\"\\u65b0\\u5efa\",\"code\":\"create\",\"codeReadonly\":true},{\"position\":{\"left\":630,\"top\":120},\"id\":\"edit\",\"type\":\"process\",\"text\":\"\\u7f16\\u8f91\",\"code\":\"edit\",\"codeReadonly\":true},{\"position\":{\"left\":975,\"top\":460},\"id\":\"stop\",\"type\":\"stop\",\"text\":\"\\u7ed3\\u675f\",\"readonly\":true,\"codeReadonly\":true},{\"position\":{\"left\":965,\"top\":245},\"id\":\"hiw5fgz8fw00\",\"type\":\"process\",\"text\":\"\\u901a\\u8fc7\",\"code\":\"pass\",\"codeReadonly\":true},{\"position\":{\"left\":815,\"top\":230},\"id\":\"hiw62q9jfyo0\",\"type\":\"result\",\"text\":\"\\u5f85\\u5ba1\\u6838\",\"toggle\":\"tooltip\",\"placement\":\"right\"},{\"position\":{\"left\":630,\"top\":310},\"id\":\"hiw7xn66b340\",\"type\":\"process\",\"text\":\"\\u62d2\\u7edd\",\"code\":\"reject\",\"codeReadonly\":true},{\"position\":{\"left\":965,\"top\":355},\"id\":\"hiw9tj54z480\",\"type\":\"process\",\"text\":\"\\u4ed8\\u6b3e\",\"code\":\"pay\",\"codeReadonly\":true},{\"from\":\"start\",\"to\":\"create\",\"id\":\"start-add\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"hiw62q9jfyo0\",\"fromPort\":\"bottom2\",\"toPort\":\"top1\",\"id\":\"hiw6qjqsyeg0\",\"type\":\"relation\",\"text\":\"\"},{\"from\":\"hiw62q9jfyo0\",\"to\":\"hiw5fgz8fw00\",\"fromPort\":\"right1\",\"toPort\":\"left1\",\"id\":\"hiw767vm2k00\",\"type\":\"relation\",\"text\":\"\"},{\"from\":\"create\",\"to\":\"edit\",\"fromPort\":\"left1\",\"toPort\":\"right1\",\"id\":\"hiw7pxtla4g0\",\"type\":\"relation\",\"text\":\"\"},{\"position\":{\"shape\":{\"porX\":1.5094339622642,\"porY\":2.7096774193548}},\"from\":\"hiw62q9jfyo0\",\"to\":\"hiw7xn66b340\",\"fromPort\":\"bottom1\",\"toPort\":\"right1\",\"id\":\"hiw8lanb9800\",\"type\":\"relation\",\"text\":\"\"},{\"from\":\"hiw7xn66b340\",\"to\":\"edit\",\"fromPort\":\"top1\",\"toPort\":\"bottom1\",\"id\":\"hiw8w5nqv800\",\"type\":\"relation\",\"text\":\"\"},{\"position\":{\"shape\":{\"porX\":-1.1711711711712,\"porY\":0.92452830188679}},\"from\":\"edit\",\"to\":\"hiw62q9jfyo0\",\"fromPort\":\"bottom3\",\"id\":\"hiw939q1zpc0\",\"type\":\"relation\",\"text\":\"\"},{\"from\":\"hiw9tj54z480\",\"to\":\"stop\",\"fromPort\":\"bottom2\",\"toPort\":\"top2\",\"id\":\"hiwa627uha80\",\"type\":\"relation\",\"text\":\"\"},{\"from\":\"hiw5fgz8fw00\",\"to\":\"hiw9tj54z480\",\"fromPort\":\"bottom2\",\"toPort\":\"top2\",\"id\":\"hiwa8wzrcjc0\",\"type\":\"relation\",\"text\":\"\"}]','','',0,0,'{\"users\":[],\"groups\":[]}','','1.0','normal','admin','2020-10-29 15:00:44','','0000-00-00 00:00:00'),(7,'','','flow','flow','','buy','flow_buy','采购','[{\"position\":{\"left\":810,\"top\":20},\"id\":\"start\",\"type\":\"start\",\"text\":\"\\u5f00\\u59cb\",\"readonly\":true,\"codeReadonly\":true},{\"position\":{\"left\":800,\"top\":120},\"id\":\"create\",\"type\":\"process\",\"text\":\"\\u65b0\\u5efa\",\"code\":\"create\",\"codeReadonly\":true},{\"position\":{\"left\":800,\"top\":220},\"id\":\"edit\",\"type\":\"process\",\"text\":\"\\u7f16\\u8f91\",\"code\":\"edit\",\"codeReadonly\":true},{\"position\":{\"left\":810,\"top\":460},\"id\":\"stop\",\"type\":\"stop\",\"text\":\"\\u7ed3\\u675f\",\"readonly\":true,\"codeReadonly\":true},{\"position\":{\"left\":800,\"top\":325},\"id\":\"fhu1cd1tzns0\",\"type\":\"process\",\"text\":\"\\u4ed8\\u6b3e\",\"code\":\"pay\",\"codeReadonly\":true},{\"from\":\"start\",\"to\":\"create\",\"id\":\"start-add\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"edit\",\"id\":\"create-edit\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"fhu1cd1tzns0\",\"to\":\"stop\",\"fromPort\":\"bottom2\",\"toPort\":\"top2\",\"id\":\"fhu20cpy0c00\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"edit\",\"to\":\"fhu1cd1tzns0\",\"fromPort\":\"bottom2\",\"id\":\"hiuza8gn06w0\",\"type\":\"relation\",\"text\":\"\"}]','','',0,0,'{\"users\":[],\"groups\":[]}','','1.0','normal','admin','2020-10-29 15:00:44','','0000-00-00 00:00:00'),(8,'','','flow','flow','','purchasing','flow_purchasing','物品采购','[{\"position\":{\"left\":670,\"top\":20},\"id\":\"start\",\"type\":\"start\",\"text\":\"\\u5f00\\u59cb\",\"readonly\":true,\"codeReadonly\":true},{\"position\":{\"left\":660,\"top\":120},\"id\":\"create\",\"type\":\"process\",\"text\":\"\\u65b0\\u5efa\",\"code\":\"create\",\"codeReadonly\":true},{\"position\":{\"left\":500,\"top\":120},\"id\":\"edit\",\"type\":\"process\",\"text\":\"\\u7f16\\u8f91\",\"code\":\"edit\",\"codeReadonly\":true},{\"position\":{\"left\":830,\"top\":410},\"id\":\"stop\",\"type\":\"stop\",\"text\":\"\\u7ed3\\u675f\",\"readonly\":true,\"codeReadonly\":true},{\"position\":{\"left\":820,\"top\":240},\"id\":\"hiwuu4qp4v40\",\"type\":\"process\",\"text\":\"\\u901a\\u8fc7\",\"code\":\"pass\",\"codeReadonly\":true},{\"position\":{\"left\":500,\"top\":330},\"id\":\"hiwuyhvkgg80\",\"type\":\"process\",\"text\":\"\\u62d2\\u7edd\",\"code\":\"reject\",\"codeReadonly\":true},{\"position\":{\"left\":675,\"top\":225},\"id\":\"hiwv2arp8rk0\",\"type\":\"result\",\"text\":\"\\u5f85\\u5ba1\\u6838\",\"toggle\":\"tooltip\",\"placement\":\"right\"},{\"from\":\"start\",\"to\":\"create\",\"id\":\"start-add\",\"type\":\"relation\",\"text\":\"\",\"codeReadonly\":true},{\"from\":\"create\",\"to\":\"edit\",\"fromPort\":\"left1\",\"toPort\":\"right1\",\"id\":\"hiwlrhab9s80\",\"type\":\"relation\",\"text\":\"\"},{\"from\":\"create\",\"to\":\"hiwv2arp8rk0\",\"fromPort\":\"bottom2\",\"id\":\"hiwv5hfpy2g0\",\"type\":\"relation\",\"text\":\"\"},{\"from\":\"hiwv2arp8rk0\",\"to\":\"hiwuu4qp4v40\",\"fromPort\":\"right1\",\"toPort\":\"left1\",\"id\":\"hiwvn764doo0\",\"type\":\"relation\",\"text\":\"\"},{\"position\":{\"shape\":{\"porX\":2.8316831683168,\"porY\":3.6428571428571}},\"from\":\"hiwv2arp8rk0\",\"to\":\"hiwuyhvkgg80\",\"fromPort\":\"bottom1\",\"toPort\":\"right1\",\"id\":\"hiwwbt879k00\",\"type\":\"relation\",\"text\":\"\"},{\"from\":\"hiwuyhvkgg80\",\"to\":\"edit\",\"fromPort\":\"top1\",\"toPort\":\"bottom1\",\"id\":\"hiwwk2c9b9k0\",\"type\":\"relation\",\"text\":\"\"},{\"position\":{\"shape\":{\"porX\":-1.3584905660377,\"porY\":1.5445544554455}},\"from\":\"edit\",\"to\":\"hiwv2arp8rk0\",\"fromPort\":\"bottom3\",\"toPort\":\"left1\",\"id\":\"hiwwqjlfr8g0\",\"type\":\"relation\",\"text\":\"\"},{\"from\":\"hiwuu4qp4v40\",\"to\":\"stop\",\"fromPort\":\"bottom2\",\"toPort\":\"top2\",\"id\":\"hiwx1p5rcg80\",\"type\":\"relation\",\"text\":\"\"}]','','',0,0,'{\"users\":[],\"groups\":[]}','','1.0','normal','admin','2020-10-29 15:00:44','admin','2019-03-29 14:46:45'),(9,'purchasing','','table','flow','','purchasegood','flow_purchasegood','采购商品','','','',0,0,'','','1.0','normal','admin','2020-10-29 15:00:44','','0000-00-00 00:00:00');
INSERT INTO `sys_workflowaction` VALUES (1,'meetingroom','browse','浏览列表','single','different','override','','menu','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(2,'meetingroom','create','新建','single','different','override','','menu','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(3,'meetingroom','edit','编辑','single','different','override','','browseandview','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(4,'meetingroom','view','查看详情','single','different','override','normal','browse','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','admin','2016-11-23 11:13:08'),(5,'meetingroom','delete','删除','single','different','override','none','browseandview','','dropdownlist',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(6,'meetingroombooking','browse','浏览列表','single','different','override','','menu','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(7,'meetingroombooking','create','新建','single','different','override','','menu','','direct',0,0,0,'[]','{\"type\":\"sql\",\"message\":\"\\u8be5\\u65f6\\u95f4\\u6bb5\\u5df2\\u88ab\\u9884\\u8ba2\",\"sql\":\"select * from flow_meetingroombooking where deleted=\'0\' and room=\'$room\' and ((begin >= \'$begin\' and end <= \'$end\') or (begin <= \'$begin\' and end >= \'$end\') or (begin > \'$begin\' and begin < \'$end\') or (end > \'$begin\' and end < \'$end\'))\",\"sqlVars\":[{\"varName\":\"room\",\"paramType\":\"form\",\"param\":\"room\"},{\"varName\":\"begin\",\"paramType\":\"form\",\"param\":\"begin\"},{\"varName\":\"end\",\"paramType\":\"form\",\"param\":\"end\"}],\"sqlResult\":\"empty\"}','[]','','','','','','','enable','admin','2020-10-30 15:40:35','admin','2016-11-23 10:49:48'),(8,'meetingroombooking','edit','编辑','single','different','override','','browseandview','','direct',0,0,0,'[]','{\"type\":\"sql\",\"message\":\"\\u8be5\\u65f6\\u95f4\\u6bb5\\u5df2\\u88ab\\u9884\\u8ba2\",\"sql\":\"select * from flow_meetingroombooking where deleted=\'0\' and room=\'$room\' and id != \'$id\' and ((begin >= \'$begin\' and end <= \'$end\') or (begin <= \'$begin\' and end >= \'$end\') or (begin > \'$begin\' and begin < \'$end\') or (end > \'$begin\' and end < \'$end\'))\",\"sqlVars\":[{\"varName\":\"room\",\"paramType\":\"form\",\"param\":\"room\"},{\"varName\":\"begin\",\"paramType\":\"form\",\"param\":\"begin\"},{\"varName\":\"end\",\"paramType\":\"form\",\"param\":\"end\"},{\"varName\":\"id\",\"paramType\":\"record\",\"param\":\"id\"}],\"sqlResult\":\"empty\"}','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(9,'meetingroombooking','view','查看详情','single','different','override','normal','browse','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','admin','2016-11-23 11:14:53'),(10,'meetingroombooking','delete','删除','single','different','override','none','browseandview','','dropdownlist',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(11,'stamp','browse','浏览列表','single','different','override','','menu','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(12,'stamp','create','新建','single','different','override','','menu','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(13,'stamp','edit','编辑','single','different','override','','browseandview','','direct',0,0,0,'[{\"conditionType\":\"data\",\"fields\":[{\"field\":\"status\",\"operator\":\"notequal\",\"param\":\"pass\",\"logicalOperator\":\"\"}],\"sql\":\"\",\"sqlResult\":\"empty\"}]','','[{\"action\":\"update\",\"table\":\"stamp\",\"conditionType\":\"data\",\"message\":\"\",\"comment\":\"\",\"fields\":[{\"field\":\"status\",\"paramType\":\"custom\",\"param\":\"wait\"}],\"conditions\":[{\"field\":\"status\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"custom\",\"param\":\"reject\"}],\"wheres\":[{\"field\":\"id\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"record\",\"param\":\"id\"}],\"sql\":\"UPDATE `flow_stamp`  SET  `status` = \'wait\' WHERE 1 AND (1  AND `id` = \'@id\' )\",\"sqlVars\":[],\"formVars\":[],\"recordVars\":[\"id\"],\"formulaVars\":[]}]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(14,'stamp','view','查看详情','single','different','override','','browse','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(15,'stamp','delete','删除','single','different','override','none','browseandview','','dropdownlist',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(16,'stamp','revoke','撤销','single','different','override','none','browseandview','','direct',0,0,0,'[{\"conditionType\":\"data\",\"fields\":[{\"field\":\"deleted\",\"operator\":\"equal\",\"param\":\"0\"},{\"field\":\"proposer\",\"operator\":\"equal\",\"param\":\"currentUser\"},{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"wait\"}],\"sql\":\"\",\"sqlResult\":\"empty\"}]','','[{\"action\":\"update\",\"table\":\"stamp\",\"conditionType\":\"data\",\"message\":\"\",\"fields\":[{\"field\":\"status\",\"paramType\":\"custom\",\"param\":\"draft\"}],\"conditions\":[],\"wheres\":[{\"field\":\"id\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"record\",\"param\":\"id\"}],\"sql\":\"UPDATE `flow_stamp`  SET  `status` = \'draft\' WHERE 1 AND (1  AND `id` = \'@id\' )\",\"sqlVars\":[],\"formVars\":[],\"recordVars\":{\"id\":\"id\"}}]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(17,'stamp','submit','提交','single','different','override','none','browseandview','','direct',0,0,0,'[{\"conditionType\":\"data\",\"fields\":[{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"draft\"},{\"field\":\"deleted\",\"operator\":\"equal\",\"param\":\"0\"},{\"field\":\"proposer\",\"operator\":\"equal\",\"param\":\"currentUser\"}],\"sql\":\"\",\"sqlResult\":\"empty\"}]','','[{\"action\":\"update\",\"table\":\"stamp\",\"conditionType\":\"data\",\"message\":\"\",\"fields\":[{\"field\":\"status\",\"paramType\":\"custom\",\"param\":\"wait\"}],\"conditions\":[],\"wheres\":[{\"field\":\"id\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"record\",\"param\":\"id\"}],\"sql\":\"UPDATE `flow_stamp`  SET  `status` = \'wait\' WHERE 1 AND (1  AND `id` = \'@id\' )\",\"sqlVars\":[],\"formVars\":[],\"recordVars\":{\"id\":\"id\"}}]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(18,'stamp','pass','通过','single','different','override','none','browseandview','','direct',0,0,0,'[{\"conditionType\":\"data\",\"fields\":[{\"field\":\"deleted\",\"operator\":\"equal\",\"param\":\"0\"},{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"wait\"}],\"sql\":\"\",\"sqlResult\":\"empty\"}]','','[{\"action\":\"update\",\"table\":\"stamp\",\"conditionType\":\"data\",\"message\":\"\",\"fields\":[{\"field\":\"status\",\"paramType\":\"custom\",\"param\":\"pass\"},{\"field\":\"reviewedBy\",\"paramType\":\"actor\",\"param\":\"actor\"},{\"field\":\"reviewedDate\",\"paramType\":\"now\",\"param\":\"now\"}],\"conditions\":[],\"wheres\":[{\"field\":\"id\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"record\",\"param\":\"id\"}],\"sql\":\"UPDATE `flow_stamp`  SET  `status` = \'pass\',  `reviewedBy` = \'$actor\',  `reviewedDate` = \'$now\' WHERE 1 AND (1  AND `id` = \'@id\' )\",\"sqlVars\":{\"reviewedBy\":\"actor\",\"reviewedDate\":\"now\"},\"formVars\":[],\"recordVars\":{\"id\":\"id\"}}]','','','','','','','enable','admin','2020-10-30 15:40:35','admin','2016-11-23 14:09:09'),(19,'stamp','reject','拒绝','single','different','override','none','browseandview','','direct',0,0,0,'[{\"conditionType\":\"data\",\"fields\":[{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"wait\"},{\"field\":\"deleted\",\"operator\":\"equal\",\"param\":\"0\"}],\"sql\":\"\",\"sqlResult\":\"empty\"}]','','[{\"action\":\"update\",\"table\":\"stamp\",\"conditionType\":\"data\",\"message\":\"\",\"fields\":[{\"field\":\"status\",\"paramType\":\"custom\",\"param\":\"reject\"},{\"field\":\"reviewedBy\",\"paramType\":\"actor\",\"param\":\"actor\"},{\"field\":\"reviewedDate\",\"paramType\":\"now\",\"param\":\"now\"}],\"conditions\":[],\"wheres\":[{\"field\":\"id\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"record\",\"param\":\"id\"}],\"sql\":\"UPDATE `flow_stamp`  SET  `status` = \'reject\',  `reviewedBy` = \'$actor\',  `reviewedDate` = \'$now\' WHERE 1 AND (1  AND `id` = \'@id\' )\",\"sqlVars\":{\"reviewedBy\":\"actor\",\"reviewedDate\":\"now\"},\"formVars\":[],\"recordVars\":{\"id\":\"id\"}}]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(20,'car','browse','浏览列表','single','different','override','','menu','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(21,'car','create','新建','single','different','override','','menu','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(22,'car','edit','编辑','single','different','override','','browseandview','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(23,'car','view','查看详情','single','different','override','normal','browse','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','admin','2016-11-23 13:18:22'),(24,'car','delete','删除','single','different','override','none','browseandview','','dropdownlist',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(25,'carbooking','browse','浏览列表','single','different','override','','menu','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(26,'carbooking','create','新建','single','different','override','','menu','','direct',0,0,0,'[]','{\"type\":\"sql\",\"message\":\"\\u8be5\\u65f6\\u95f4\\u6bb5\\u5df2\\u88ab\\u9884\\u8ba2\",\"sql\":\"select * from flow_carbooking where deleted=\'0\' and car=\'$car\' and ((begin >= \'$begin\' and end <= \'$end\') or (begin <= \'$begin\' and end >= \'$end\') or (begin > \'$begin\' and begin < \'$end\') or (end > \'$begin\' and end < \'$end\'))\",\"sqlVars\":[{\"varName\":\"car\",\"paramType\":\"form\",\"param\":\"car\"},{\"varName\":\"begin\",\"paramType\":\"form\",\"param\":\"begin\"},{\"varName\":\"end\",\"paramType\":\"form\",\"param\":\"end\"}],\"sqlResult\":\"empty\"}','[]','','','','','','','enable','admin','2020-10-30 15:40:35','admin','2016-11-23 13:36:02'),(27,'carbooking','edit','编辑','single','different','override','','browseandview','','direct',0,0,0,'[{\"conditionType\":\"data\",\"fields\":[{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"wait\",\"logicalOperator\":\"\"},{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"reject\",\"logicalOperator\":\"or\"}],\"sql\":\"\",\"sqlResult\":\"empty\"}]','{\"type\":\"sql\",\"message\":\"\\u8be5\\u65f6\\u95f4\\u6bb5\\u5df2\\u88ab\\u9884\\u8ba2\",\"sql\":\"select * from flow_carbooking where deleted=\'0\' and car = \'$car\' and id != \'$id\' and  ((begin >= \'$begin\' and end <= \'$end\') or (begin <= \'$begin\' and end >= \'$end\') or (begin > \'$begin\' and begin < \'$end\') or (end > \'$begin\' and end < \'$end\'))\",\"sqlVars\":[{\"varName\":\"car\",\"paramType\":\"form\",\"param\":\"car\"},{\"varName\":\"begin\",\"paramType\":\"form\",\"param\":\"begin\"},{\"varName\":\"end\",\"paramType\":\"form\",\"param\":\"end\"},{\"varName\":\"id\",\"paramType\":\"record\",\"param\":\"id\"}],\"sqlResult\":\"empty\"}','[{\"action\":\"update\",\"table\":\"carbooking\",\"conditionType\":\"data\",\"message\":\"\",\"comment\":\"\",\"fields\":[{\"field\":\"status\",\"paramType\":\"custom\",\"param\":\"wait\"}],\"conditions\":[{\"field\":\"status\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"custom\",\"param\":\"reject\"}],\"wheres\":[{\"field\":\"id\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"record\",\"param\":\"id\"}],\"sql\":\"UPDATE `flow_carbooking`  SET  `status` = \'wait\' WHERE 1 AND (1  AND `id` = \'@id\' )\",\"sqlVars\":[],\"formVars\":[],\"recordVars\":[\"id\"],\"formulaVars\":[]}]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(28,'carbooking','view','查看详情','single','different','override','normal','browse','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','admin','2016-11-23 13:25:59'),(29,'carbooking','delete','删除','single','different','override','none','browseandview','','dropdownlist',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(30,'carbooking','pass','通过','single','different','override','none','browseandview','','direct',0,0,0,'[{\"conditionType\":\"data\",\"fields\":[{\"field\":\"deleted\",\"operator\":\"equal\",\"param\":\"0\"},{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"wait\"}],\"sql\":\"\",\"sqlResult\":\"empty\"}]','','[{\"action\":\"update\",\"table\":\"carbooking\",\"conditionType\":\"data\",\"message\":\"\",\"fields\":[{\"field\":\"status\",\"paramType\":\"custom\",\"param\":\"pass\"}],\"conditions\":[],\"wheres\":[{\"field\":\"id\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"record\",\"param\":\"id\"}],\"sql\":\"UPDATE `flow_carbooking`  SET  `status` = \'pass\' WHERE 1 AND (1  AND `id` = \'@id\' )\",\"sqlVars\":[],\"formVars\":[],\"recordVars\":{\"id\":\"id\"}}]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(31,'carbooking','reject','拒绝','single','different','override','none','browseandview','','direct',0,0,0,'[{\"conditionType\":\"data\",\"fields\":[{\"field\":\"deleted\",\"operator\":\"equal\",\"param\":\"0\"},{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"wait\"}],\"sql\":\"\",\"sqlResult\":\"empty\"}]','','[{\"action\":\"update\",\"table\":\"carbooking\",\"conditionType\":\"data\",\"message\":\"\",\"fields\":[{\"field\":\"status\",\"paramType\":\"custom\",\"param\":\"reject\"}],\"conditions\":[],\"wheres\":[{\"field\":\"id\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"record\",\"param\":\"id\"}],\"sql\":\"UPDATE `flow_carbooking`  SET  `status` = \'reject\' WHERE 1 AND (1  AND `id` = \'@id\' )\",\"sqlVars\":[],\"formVars\":[],\"recordVars\":{\"id\":\"id\"}}]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(32,'collect','browse','浏览列表','single','different','override','','menu','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(33,'collect','create','新建','single','different','override','','menu','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(34,'collect','edit','编辑','single','different','override','','browseandview','','direct',0,0,0,'[{\"conditionType\":\"data\",\"fields\":[{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"wait\",\"logicalOperator\":\"\"},{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"reject\",\"logicalOperator\":\"or\"}],\"sql\":\"\",\"sqlResult\":\"empty\"}]','','[{\"action\":\"update\",\"table\":\"collect\",\"conditionType\":\"data\",\"message\":\"\",\"comment\":\"\",\"fields\":[{\"field\":\"status\",\"paramType\":\"custom\",\"param\":\"wait\"}],\"conditions\":[{\"field\":\"status\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"custom\",\"param\":\"reject\"}],\"wheres\":[{\"field\":\"id\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"record\",\"param\":\"id\"}],\"sql\":\"UPDATE `flow_collect`  SET  `status` = \'wait\' WHERE 1 AND (1  AND `id` = \'@id\' )\",\"sqlVars\":[],\"formVars\":[],\"recordVars\":[\"id\"],\"formulaVars\":[]}]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(35,'collect','view','查看详情','single','different','override','normal','browse','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','admin','2016-11-23 14:00:40'),(36,'collect','delete','删除','single','different','override','none','browseandview','','dropdownlist',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(37,'collect','pass','通过','single','different','override','none','browseandview','','direct',0,0,0,'[{\"conditionType\":\"data\",\"fields\":[{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"wait\",\"logicalOperator\":\"and\"},{\"field\":\"deleted\",\"operator\":\"equal\",\"param\":\"0\",\"logicalOperator\":\"and\"}],\"sql\":\"\",\"sqlResult\":\"empty\"}]','','[{\"action\":\"update\",\"table\":\"collect\",\"conditionType\":\"data\",\"message\":\"\",\"comment\":\"\",\"fields\":[{\"field\":\"status\",\"paramType\":\"custom\",\"param\":\"pass\"},{\"field\":\"reviewedBy\",\"paramType\":\"actor\",\"param\":\"actor\"},{\"field\":\"reviewedDate\",\"paramType\":\"now\",\"param\":\"now\"}],\"conditions\":[],\"wheres\":[{\"field\":\"id\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"record\",\"param\":\"id\"}],\"sql\":\"UPDATE `flow_collect`  SET  `status` = \'pass\',  `reviewedBy` = \'$actor\',  `reviewedDate` = \'$now\' WHERE 1 AND (1  AND `id` = \'@id\' )\",\"sqlVars\":[\"actor\",\"now\"],\"formVars\":[],\"recordVars\":[\"id\"],\"formulaVars\":[]}]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(38,'collect','reject','拒绝','single','different','override','none','browseandview','','direct',0,0,0,'[{\"conditionType\":\"data\",\"fields\":[{\"field\":\"deleted\",\"operator\":\"equal\",\"param\":\"0\"},{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"wait\"}],\"sql\":\"\",\"sqlResult\":\"empty\"}]','','[{\"action\":\"update\",\"table\":\"collect\",\"conditionType\":\"data\",\"message\":\"\",\"comment\":\"\",\"fields\":[{\"field\":\"status\",\"paramType\":\"custom\",\"param\":\"reject\"},{\"field\":\"reviewedBy\",\"paramType\":\"actor\",\"param\":\"actor\"},{\"field\":\"reviewedDate\",\"paramType\":\"now\",\"param\":\"now\"}],\"conditions\":[],\"wheres\":[{\"field\":\"id\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"record\",\"param\":\"id\"}],\"sql\":\"UPDATE `flow_collect`  SET  `status` = \'reject\',  `reviewedBy` = \'$actor\',  `reviewedDate` = \'$now\' WHERE 1 AND (1  AND `id` = \'@id\' )\",\"sqlVars\":[\"actor\",\"now\"],\"formVars\":[],\"recordVars\":[\"id\"],\"formulaVars\":[]}]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(39,'collect','pay','付款','single','different','override','modal','browseandview','','direct',0,0,0,'[{\"conditionType\":\"data\",\"fields\":[{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"pass\"},{\"field\":\"deleted\",\"operator\":\"equal\",\"param\":\"0\"}],\"sql\":\"\",\"sqlResult\":\"empty\"}]','','[{\"action\":\"update\",\"table\":\"collect\",\"conditionType\":\"data\",\"message\":\"\",\"fields\":[{\"field\":\"status\",\"paramType\":\"custom\",\"param\":\"closed\"}],\"conditions\":[],\"wheres\":[{\"field\":\"id\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"record\",\"param\":\"id\"}],\"sql\":\"UPDATE `flow_collect`  SET  `status` = \'closed\' WHERE 1 AND (1  AND `id` = \'@id\' )\",\"sqlVars\":[],\"formVars\":[],\"recordVars\":{\"id\":\"id\"}},{\"action\":\"insert\",\"table\":\"trade\",\"conditionType\":\"data\",\"message\":\"\",\"fields\":[{\"field\":\"depositor\",\"paramType\":\"form\",\"param\":\"depositor\"},{\"field\":\"category\",\"paramType\":\"form\",\"param\":\"category\"},{\"field\":\"type\",\"paramType\":\"custom\",\"param\":\"out\"},{\"field\":\"desc\",\"paramType\":\"record\",\"param\":\"reason\"},{\"field\":\"money\",\"paramType\":\"record\",\"param\":\"money\"},{\"field\":\"handlers\",\"paramType\":\"actor\",\"param\":\"actor\"},{\"field\":\"date\",\"paramType\":\"today\",\"param\":\"today\"},{\"field\":\"createdBy\",\"paramType\":\"actor\",\"param\":\"actor\"},{\"field\":\"createdDate\",\"paramType\":\"now\",\"param\":\"now\"}],\"conditions\":[],\"wheres\":[],\"sql\":\"INSERT INTO `cash_trade` (`depositor`, `category`, `type`, `desc`, `money`, `handlers`, `date`, `createdBy`, `createdDate`) VALUES (\'#depositor\', \'#category\', \'out\', \'@reason\', \'@money\', \'$actor\', \'$today\', \'$actor\', \'$now\') \",\"sqlVars\":{\"handlers\":\"actor\",\"date\":\"today\",\"createdBy\":\"actor\",\"createdDate\":\"now\"},\"formVars\":{\"depositor\":\"depositor\",\"category\":\"category\"},\"recordVars\":{\"desc\":\"reason\",\"money\":\"money\"}}]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(40,'buy','browse','浏览列表','single','different','override','','menu','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(41,'buy','create','新建','single','different','override','','menu','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(42,'buy','edit','编辑','single','different','override','','browseandview','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(43,'buy','view','查看详情','single','different','override','','browse','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(44,'buy','delete','删除','single','different','override','none','browseandview','','dropdownlist',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(45,'buy','pay','付款','single','different','override','modal','browseandview','','direct',0,0,0,'[{\"conditionType\":\"data\",\"fields\":[{\"field\":\"deleted\",\"operator\":\"equal\",\"param\":\"0\"},{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"unpaid\"}],\"sql\":\"\",\"sqlResult\":\"empty\"}]','','[{\"action\":\"update\",\"table\":\"buy\",\"conditionType\":\"data\",\"message\":\"\",\"fields\":[{\"field\":\"status\",\"paramType\":\"custom\",\"param\":\"paid\"}],\"conditions\":[],\"wheres\":[{\"field\":\"id\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"record\",\"param\":\"id\"}],\"sql\":\"UPDATE `flow_buy`  SET  `status` = \'paid\' WHERE 1 AND (1  AND `id` = \'@id\' )\",\"sqlVars\":[],\"formVars\":[],\"recordVars\":{\"id\":\"id\"}},{\"action\":\"insert\",\"table\":\"trade\",\"conditionType\":\"data\",\"message\":\"\",\"fields\":[{\"field\":\"depositor\",\"paramType\":\"form\",\"param\":\"depositor\"},{\"field\":\"category\",\"paramType\":\"form\",\"param\":\"category\"},{\"field\":\"trader\",\"paramType\":\"record\",\"param\":\"provider\"},{\"field\":\"type\",\"paramType\":\"custom\",\"param\":\"out\"},{\"field\":\"handlers\",\"paramType\":\"actor\",\"param\":\"actor\"},{\"field\":\"desc\",\"paramType\":\"record\",\"param\":\"desc\"},{\"field\":\"money\",\"paramType\":\"record\",\"param\":\"money\"},{\"field\":\"date\",\"paramType\":\"today\",\"param\":\"today\"},{\"field\":\"createdBy\",\"paramType\":\"actor\",\"param\":\"actor\"},{\"field\":\"createdDate\",\"paramType\":\"now\",\"param\":\"now\"}],\"conditions\":[],\"wheres\":[],\"sql\":\"INSERT INTO `cash_trade` (`depositor`, `category`, `trader`, `type`, `handlers`, `desc`, `money`, `date`, `createdBy`, `createdDate`) VALUES (\'#depositor\', \'#category\', \'@provider\', \'out\', \'$actor\', \'@desc\', \'@money\', \'$today\', \'$actor\', \'$now\') \",\"sqlVars\":{\"handlers\":\"actor\",\"date\":\"today\",\"createdBy\":\"actor\",\"createdDate\":\"now\"},\"formVars\":{\"depositor\":\"depositor\",\"category\":\"category\"},\"recordVars\":{\"trader\":\"provider\",\"desc\":\"desc\",\"money\":\"money\"}}]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(46,'purchasing','browse','浏览列表','single','different','override','','menu','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(47,'purchasing','create','新建','single','different','override','','menu','','direct',0,0,0,'[]','','[{\"action\":\"update\",\"table\":\"purchasing\",\"conditionType\":\"data\",\"message\":\"\",\"comment\":\"\",\"fields\":[{\"field\":\"status\",\"paramType\":\"custom\",\"param\":\"wait\"}],\"conditions\":[{\"field\":\"status\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"custom\",\"param\":\"reject\"}],\"wheres\":[{\"field\":\"id\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"record\",\"param\":\"id\"}],\"sql\":\"UPDATE `flow_purchasing`  SET  `status` = \'wait\' WHERE 1 AND (1  AND `id` = \'@id\' )\",\"sqlVars\":[],\"formVars\":[],\"recordVars\":[\"id\"],\"formulaVars\":[]}]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(48,'purchasing','edit','编辑','single','different','override','','browseandview','','direct',0,0,0,'[{\"conditionType\":\"data\",\"fields\":[{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"wait\",\"logicalOperator\":\"\"},{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"reject\",\"logicalOperator\":\"or\"}],\"sql\":\"\",\"sqlResult\":\"empty\"}]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(49,'purchasing','view','查看详情','single','different','override','','browse','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(50,'purchasing','delete','删除','single','different','override','none','browseandview','','dropdownlist',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(51,'purchasegood','browse','浏览列表','single','different','override','','menu','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(52,'purchasegood','create','新建','single','different','override','','menu','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(53,'purchasegood','edit','编辑','single','different','override','','browseandview','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(54,'purchasegood','view','查看详情','single','different','override','','browse','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(55,'purchasegood','delete','删除','single','different','override','none','browseandview','','dropdownlist',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(56,'purchasing','pass','通过','single','different','override','none','browseandview','','direct',0,0,0,'[{\"conditionType\":\"data\",\"fields\":[{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"wait\",\"logicalOperator\":\"and\"}],\"sql\":\"\",\"sqlResult\":\"empty\"}]','','[{\"action\":\"update\",\"table\":\"purchasing\",\"conditionType\":\"data\",\"message\":\"\",\"comment\":\"\",\"fields\":[{\"field\":\"status\",\"paramType\":\"custom\",\"param\":\"pass\"}],\"conditions\":[],\"wheres\":[{\"field\":\"id\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"record\",\"param\":\"id\"}],\"sql\":\"UPDATE `flow_purchasing`  SET  `status` = \'pass\' WHERE 1 AND (1  AND `id` = \'@id\' )\",\"sqlVars\":[],\"formVars\":[],\"recordVars\":{\"id\":\"id\"}},{\"action\":\"insert\",\"table\":\"payable\",\"conditionType\":\"data\",\"message\":\"\",\"comment\":\"\\u5ba1\\u6279\\u901a\\u8fc7\\u540e\\u521b\\u5efa\\u4e00\\u6761\\u5e94\\u4ed8\\u6b3e\\u8bb0\\u5f55\\u3002\",\"fields\":[{\"field\":\"type\",\"paramType\":\"custom\",\"param\":\"payable\"},{\"field\":\"parent\",\"paramType\":\"custom\",\"param\":\"-1\"},{\"field\":\"origin\",\"paramType\":\"custom\",\"param\":\"\\u7269\\u54c1\\u91c7\\u8d2d\"},{\"field\":\"trader\",\"paramType\":\"record\",\"param\":\"provider\"},{\"field\":\"deserved\",\"paramType\":\"record\",\"param\":\"money\"},{\"field\":\"balance\",\"paramType\":\"record\",\"param\":\"money\"},{\"field\":\"desc\",\"paramType\":\"record\",\"param\":\"desc\"},{\"field\":\"custom\",\"paramType\":\"custom\",\"param\":\"1\"},{\"field\":\"createdBy\",\"paramType\":\"actor\",\"param\":\"actor\"},{\"field\":\"createdDate\",\"paramType\":\"now\",\"param\":\"now\"},{\"field\":\"editedBy\",\"paramType\":\"actor\",\"param\":\"actor\"},{\"field\":\"editedDate\",\"paramType\":\"now\",\"param\":\"now\"}],\"conditions\":[],\"wheres\":[],\"sql\":\"INSERT INTO `cash_fund` (`type`,`parent`,`origin`,`trader`,`deserved`,`balance`,`desc`,`custom`,`createdBy`,`createdDate`,`editedBy`,`editedDate`) VALUES (\'payable\',\'-1\',\'\\u7269\\u54c1\\u91c7\\u8d2d\',\'@provider\',\'@money\',\'@money\',\'@desc\',\'1\',\'$actor\',\'$now\',\'$actor\',\'$now\') \",\"sqlVars\":{\"createdBy\":\"actor\",\"createdDate\":\"now\",\"editedBy\":\"actor\",\"editedDate\":\"now\"},\"formVars\":[],\"recordVars\":{\"trader\":\"provider\",\"deserved\":\"money\",\"balance\":\"money\",\"desc\":\"desc\"}}]','','','','','','','enable','admin','2020-10-30 15:40:35','admin','2019-03-28 15:15:28'),(57,'purchasing','reject','拒绝','single','different','override','none','browseandview','','direct',0,0,0,'[{\"conditionType\":\"data\",\"fields\":[{\"field\":\"status\",\"operator\":\"equal\",\"param\":\"wait\",\"logicalOperator\":\"and\"}],\"sql\":\"\",\"sqlResult\":\"empty\"}]','','[{\"action\":\"update\",\"table\":\"purchasing\",\"conditionType\":\"data\",\"message\":\"\",\"comment\":\"\",\"fields\":[{\"field\":\"status\",\"paramType\":\"custom\",\"param\":\"reject\"}],\"conditions\":[],\"wheres\":[{\"field\":\"id\",\"logicalOperator\":\"and\",\"operator\":\"equal\",\"paramType\":\"record\",\"param\":\"id\"}],\"sql\":\"UPDATE `flow_purchasing`  SET  `status` = \'reject\' WHERE 1 AND (1  AND `id` = \'@id\' )\",\"sqlVars\":[],\"formVars\":[],\"recordVars\":{\"id\":\"id\"}}]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(58,'buy','export','导出数据','single','different','override','none','menu','','direct',0,0,0,'[]','','[]','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 16:01:24'),(59,'car','export','导出数据','single','different','override','none','menu','','direct',0,0,0,'[]','','[]','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:54:52'),(60,'carbooking','export','导出数据','single','different','override','none','menu','','direct',0,0,0,'[]','','[]','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:57:38'),(61,'collect','export','导出数据','single','different','override','none','menu','','direct',0,0,0,'[]','','[]','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:59:37'),(62,'meetingroom','export','导出数据','single','different','override','none','menu','','direct',0,0,0,'[]','','[]','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:41:03'),(63,'meetingroombooking','export','导出数据','single','different','override','none','menu','','direct',0,0,0,'[]','','[]','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:43:15'),(64,'purchasegood','export','导出数据','single','different','override','none','menu','','direct',0,0,0,'[]','','[]','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(65,'purchasing','export','导出数据','single','different','override','none','menu','','direct',0,0,0,'[]','','[]','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 16:02:26'),(66,'stamp','export','导出数据','single','different','override','none','menu','','direct',0,0,0,'[]','','[]','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:52:05'),(67,'purchasing','batchcreate','批量新建','batch','different','override','normal','menu','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','admin','2020-09-29 11:07:22'),(68,'purchasing','batchedit','批量编辑','batch','different','override','normal','browse','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(69,'purchasing','link','关联数据','single','same','override','none','view','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 16:02:33'),(70,'purchasing','unlink','移除数据','single','same','override','none','view','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 16:02:49'),(71,'purchasing','exporttemplate','下载模板','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 16:02:54'),(72,'purchasing','import','导入数据','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 16:03:00'),(73,'purchasing','showimport','导入确认','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 16:03:06'),(74,'buy','batchcreate','批量新建','batch','different','override','normal','menu','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(75,'buy','batchedit','批量编辑','batch','different','override','normal','browse','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(76,'buy','link','关联数据','single','same','override','none','view','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 16:01:33'),(77,'buy','unlink','移除数据','single','same','override','none','view','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 16:01:38'),(78,'buy','exporttemplate','下载模板','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 16:01:48'),(79,'buy','import','导入数据','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 16:01:54'),(80,'buy','showimport','导入确认','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 16:01:59'),(81,'collect','batchcreate','批量新建','batch','different','override','normal','menu','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(82,'collect','batchedit','批量编辑','batch','different','override','normal','browse','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(83,'collect','link','关联数据','single','same','override','none','view','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:59:43'),(84,'collect','unlink','移除数据','single','same','override','none','view','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:59:50'),(85,'collect','exporttemplate','下载模板','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:59:57'),(86,'collect','import','导入数据','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 16:00:05'),(87,'collect','showimport','导入确认','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 16:00:13'),(88,'carbooking','batchcreate','批量新建','batch','different','override','normal','menu','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(89,'carbooking','batchedit','批量编辑','batch','different','override','normal','browse','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(90,'carbooking','link','关联数据','single','same','override','none','view','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:57:50'),(91,'carbooking','unlink','移除数据','single','same','override','none','view','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:57:58'),(92,'carbooking','exporttemplate','下载模板','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:58:04'),(93,'carbooking','import','导入数据','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:58:13'),(94,'carbooking','showimport','导入确认','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:58:19'),(95,'car','batchcreate','批量新建','batch','different','override','normal','menu','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(96,'car','batchedit','批量编辑','batch','different','override','normal','browse','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(97,'car','link','关联数据','single','same','override','none','view','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:54:59'),(98,'car','unlink','移除数据','single','same','override','none','view','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:55:04'),(99,'car','exporttemplate','下载模板','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:55:10'),(100,'car','import','导入数据','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:55:16'),(101,'car','showimport','导入确认','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:55:21'),(102,'stamp','batchcreate','批量新建','batch','different','override','normal','menu','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(103,'stamp','batchedit','批量编辑','batch','different','override','normal','browse','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(104,'stamp','link','关联数据','single','same','override','none','view','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:52:18'),(105,'stamp','unlink','移除数据','single','same','override','none','view','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:52:10'),(106,'stamp','exporttemplate','下载模板','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:52:24'),(107,'stamp','import','导入数据','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:52:29'),(108,'stamp','showimport','导入确认','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:52:39'),(109,'meetingroombooking','batchcreate','批量新建','batch','different','override','normal','menu','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(110,'meetingroombooking','batchedit','批量编辑','batch','different','override','normal','browse','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(111,'meetingroombooking','link','关联数据','single','same','override','none','view','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:43:37'),(112,'meetingroombooking','unlink','移除数据','single','same','override','none','view','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:43:43'),(113,'meetingroombooking','exporttemplate','下载模板','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:43:48'),(114,'meetingroombooking','import','导入数据','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:43:53'),(115,'meetingroombooking','showimport','导入确认','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:43:58'),(116,'meetingroom','batchcreate','批量新建','batch','different','override','normal','menu','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(117,'meetingroom','batchedit','批量编辑','batch','different','override','normal','browse','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(118,'meetingroom','link','关联数据','single','same','override','none','view','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:41:13'),(119,'meetingroom','unlink','移除数据','single','same','override','none','view','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:42:00'),(120,'meetingroom','exporttemplate','下载模板','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:41:24'),(121,'meetingroom','import','导入数据','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:41:30'),(122,'meetingroom','showimport','导入确认','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','disable','admin','2020-10-30 15:40:35','admin','2020-10-30 15:41:35'),(129,'car','carbooking_create','预订','single','same','override','normal','menu','','direct',0,0,1,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','admin','2020-10-21 10:51:00'),(130,'car','carbooking_batchcreate','批量预订','batch','different','override','normal','menu','','direct',0,0,1,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','admin','2020-10-21 10:51:07'),(127,'meetingroom','meetingroombooking_create','预订','single','same','override','normal','menu','','direct',0,0,1,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','admin','2020-10-21 10:53:43'),(128,'meetingroom','meetingroombooking_batchcreate','批量预订','batch','different','override','normal','menu','','direct',0,0,1,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','admin','2020-10-21 10:53:49'),(131,'meetingroom','report','报表','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(132,'meetingroombooking','report','报表','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(133,'stamp','report','报表','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(134,'car','report','报表','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(135,'carbooking','report','报表','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(136,'collect','report','报表','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(137,'buy','report','报表','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(138,'purchasing','report','报表','single','same','override','none','menu','','direct',0,0,0,'','','','','','','','','','enable','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00');
INSERT INTO `sys_workflowdatasource` VALUES (1,'system','订单','{\"app\":\"crm\",\"module\":\"order\",\"method\":\"getPairs\",\"methodDesc\":\"Get order pairs.\",\"params\":[{\"name\":\"customer\",\"type\":\"int\",\"desc\":\"\",\"value\":\"0\"},{\"name\":\"status\",\"type\":\"string\",\"desc\":\"\",\"value\":\"\"}]}','','','','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(2,'system','合同','{\"app\":\"crm\",\"module\":\"contract\",\"method\":\"getPairs\",\"methodDesc\":\"Get contract pairs.\",\"params\":[{\"name\":\"customerID\",\"type\":\"int\",\"desc\":\"\",\"value\":\"0\"}]}','','','','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(3,'system','客户','{\"app\":\"crm\",\"module\":\"customer\",\"method\":\"getPairs\",\"methodDesc\":\"Get customer pairs.\",\"params\":[{\"name\":\"relation\",\"type\":\"string\",\"desc\":\"\",\"value\":\"customer\"},{\"name\":\"emptyOption\",\"type\":\"bool\",\"desc\":\"\",\"value\":\"1\"}]}','','','','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(4,'system','供应商','{\"app\":\"crm\",\"module\":\"customer\",\"method\":\"getPairs\",\"methodDesc\":\"Get customer pairs.\",\"params\":[{\"name\":\"relation\",\"type\":\"string\",\"desc\":\"\",\"value\":\"provider\"},{\"name\":\"emptyOption\",\"type\":\"bool\",\"desc\":\"\",\"value\":\"1\"}]}','','','','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(5,'system','联系人','{\"app\":\"crm\",\"module\":\"contact\",\"method\":\"getPairs\",\"methodDesc\":\"Get common selecter of contact.\",\"params\":[{\"name\":\"customer\",\"type\":\"int\",\"desc\":\"\",\"value\":\"0\"},{\"name\":\"emptyOption\",\"type\":\"bool\",\"desc\":\"\",\"value\":\"1\"},{\"name\":\"status\",\"type\":\"string\",\"desc\":\"\",\"value\":\"normal\"}]}','','','','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(6,'system','产品','{\"app\":\"crm\",\"module\":\"product\",\"method\":\"getPairs\",\"methodDesc\":\"Get product pairs.\",\"params\":[{\"name\":\"status\",\"type\":\"string\",\"desc\":\"\",\"value\":\"\"},{\"name\":\"orderBy\",\"type\":\"string\",\"desc\":\"\",\"value\":\"id_desc\"}]}','','','','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(7,'sql','会议室','select id, name from flow_meetingroom where deleted = \'0\';','view_datasource_7','id','name','admin','2020-10-30 15:40:35','admin','2020-10-30 16:23:36'),(8,'option','设备','{\"computer\":\"\\u7535\\u8111\",\"projector\":\"\\u6295\\u5f71\\u4eea\",\"micphone\":\"\\u9ea6\\u514b\\u98ce\",\"audio\":\"\\u97f3\\u54cd\",\"whiteboard\":\"\\u767d\\u677f\"}','','','','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(9,'option','工作日','{\"1\":\"\\u5468\\u4e00\",\"2\":\"\\u5468\\u4e8c\",\"3\":\"\\u5468\\u4e09\",\"4\":\"\\u5468\\u56db\",\"5\":\"\\u5468\\u4e94\",\"6\":\"\\u5468\\u516d\",\"7\":\"\\u5468\\u65e5\"}','','','','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(10,'system','账号','{\"app\":\"cash\",\"module\":\"depositor\",\"method\":\"getPairs\",\"methodDesc\":\"Get depositor option menu.\",\"params\":[]}','','','','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00'),(11,'system','支出科目','{\"app\":\"sys\",\"module\":\"tree\",\"method\":\"getPairs\",\"methodDesc\":\"Get the id => name pairs of some categories.\",\"params\":[{\"name\":\"categories\",\"type\":\"string\",\"desc\":\"the category lists\",\"value\":\"\"},{\"name\":\"type\",\"type\":\"string\",\"desc\":\"the type\",\"value\":\"out\"}]}','','','','admin','2020-10-30 15:40:35','','0000-00-00 00:00:00');
INSERT INTO `sys_workflowfield` VALUES (1,'meetingroom','id','mediumint','8','编号','label','','[]','','2','',5,2,0,'1','1','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(2,'meetingroom','parent','mediumint','8','父流程ID','label','','[]','0','','',6,1,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(3,'meetingroom','createdBy','varchar','30','由谁创建','select','','user','','','',7,1,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(4,'meetingroom','createdDate','datetime','','创建日期','datetime','','[]','','','',8,1,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(5,'meetingroom','editedBy','varchar','30','由谁编辑','select','','user','','','',9,0,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(6,'meetingroom','editedDate','datetime','','编辑日期','datetime','','[]','','','',10,0,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(7,'meetingroom','deleted','varchar','200','是否删除','radio','','[\"\\u672a\\u5220\\u9664\",\"\\u5df2\\u5220\\u9664\"]','0','','',12,0,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(8,'meetingroom','name','varchar','200','名称','input','','{}','','1','',0,1,5,'1','1','1','',0,'0','admin','2020-11-02 10:48:03','admin','2016-11-23 11:14:10'),(9,'meetingroom','position','varchar','200','位置','select','','{\"1\":\"\\u4e00\\u697c\",\"2\":\"\\u4e8c\\u697c\",\"3\":\"\\u4e09\\u697c\",\"4\":\"\\u56db\\u697c\",\"5\":\"\\u4e94\\u697c\"}','','1','',1,0,1,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','admin','2016-11-23 10:24:40'),(10,'meetingroom','seats','smallint','','容纳人数','integer','','[]','','1','',2,3,2,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','admin','2020-09-28 16:43:16'),(11,'meetingroom','equipment','text','','设备','checkbox','','8','','1','',3,4,3,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(12,'meetingroom','workday','text','','开放时间','checkbox','','9','','1','',4,5,4,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','admin','2016-11-23 10:39:48'),(13,'meetingroombooking','id','mediumint','','编号','label','','{}','','2','',6,1,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(14,'meetingroombooking','parent','mediumint','8','父流程ID','label','','[]','0','','',7,1,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(15,'meetingroombooking','createdBy','varchar','30','由谁创建','select','','user','','','',8,1,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(16,'meetingroombooking','createdDate','datetime','','创建日期','datetime','','[]','','','',9,1,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(17,'meetingroombooking','editedBy','varchar','30','由谁编辑','select','','user','','','',10,1,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(18,'meetingroombooking','editedDate','datetime','','编辑日期','datetime','','[]','','','',11,1,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(19,'meetingroombooking','deleted','varchar','200','是否删除','radio','','[\"\\u672a\\u5220\\u9664\",\"\\u5df2\\u5220\\u9664\"]','0','','',13,0,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(20,'meetingroombooking','room','varchar','8','会议室','select','','prevModule','','1','',0,0,0,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(21,'meetingroombooking','begin','datetime','','开始时间','datetime','','{}','','1,3','',1,1,1,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(22,'meetingroombooking','end','datetime','','结束时间','datetime','','{}','','1,3','',2,2,2,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(23,'meetingroombooking','orderedBy','varchar','30','由谁预订','select','','user','','1','',3,3,3,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(24,'meetingroombooking','orderedDate','datetime','','预订时间','datetime','','{}','','1,3','',4,4,4,'1','1','1','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(25,'meetingroombooking','desc','varchar','200','描述','input','','{}','','','',5,5,5,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(26,'stamp','id','mediumint','','编号','label','','{}','','2','',9,2,0,'1','1','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(27,'stamp','parent','mediumint','8','父流程ID','label','','[]','0','','',10,0,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(28,'stamp','createdBy','varchar','30','由谁创建','select','','user','','','',11,0,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(29,'stamp','createdDate','datetime','','创建日期','datetime','','{}','','','',12,0,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(30,'stamp','editedBy','varchar','30','由谁编辑','select','','user','','','',13,0,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(31,'stamp','editedDate','datetime','','编辑日期','datetime','','{}','','','',14,0,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(32,'stamp','deleted','varchar','200','是否删除','radio','','[\"\\u672a\\u5220\\u9664\",\"\\u5df2\\u5220\\u9664\"]','0','','',16,0,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(33,'stamp','proposer','varchar','30','申请人','select','','user','','1','',0,1,1,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(34,'stamp','reason','varchar','200','申请事由','input','','{}','','1','',4,0,2,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(35,'stamp','begin','datetime','','开始时间','datetime','','{}','','1','',1,3,3,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(36,'stamp','end','datetime','','结束时间','datetime','','{}','','1','',2,4,4,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(37,'stamp','type','text','','印章类型','checkbox','','{\"1\":\"\\u516c\\u7ae0\",\"2\":\"\\u6cd5\\u4eba\\u7ae0\",\"3\":\"\\u5408\\u540c\\u7ae0\",\"4\":\"\\u8d22\\u52a1\\u7ae0\",\"5\":\"\\u53d1\\u7968\\u7ae0\"}','','1','',3,5,5,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(38,'stamp','desc','varchar','200','备注','input','','{}','','','',6,6,6,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(39,'stamp','status','varchar','200','状态','select','','{\"draft\":\"\\u8349\\u7a3f\",\"wait\":\"\\u5f85\\u5ba1\\u6279\",\"pass\":\"\\u901a\\u8fc7\",\"reject\":\"\\u62d2\\u7edd\"}','wait','1','',5,7,7,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','admin','2016-11-23 11:25:25'),(40,'stamp','reviewedBy','varchar','30','审批人','select','','user','','1','',7,8,8,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','admin','2016-11-23 11:23:27'),(41,'stamp','reviewedDate','datetime','','审批时间','datetime','','{}','','1','',8,9,9,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(42,'car','id','mediumint','','编号','label','','{}','','2','',7,1,0,'1','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(43,'car','parent','mediumint','8','父流程ID','label','','[]','0','','',8,1,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(44,'car','createdBy','varchar','30','由谁创建','select','','user','','','',9,1,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(45,'car','createdDate','datetime','','创建日期','datetime','','[]','','','',10,1,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(46,'car','editedBy','varchar','30','由谁编辑','select','','user','','','',11,0,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(47,'car','editedDate','datetime','','编辑日期','datetime','','[]','','','',12,0,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(48,'car','deleted','varchar','200','是否删除','radio','','[\"\\u672a\\u5220\\u9664\",\"\\u5df2\\u5220\\u9664\"]','0','','',14,0,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(49,'car','type','varchar','200','品牌','select','','{\"audi\":\"\\u5965\\u8fea\",\"benz\":\"\\u5954\\u9a70\",\"vw\":\"\\u5927\\u4f17\"}','','1','',0,1,1,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','admin','2020-11-02 13:48:37'),(50,'car','code','varchar','200','车牌号','input','','{}','','1','',1,0,7,'1','1','1','',0,'0','admin','2020-11-02 10:48:03','admin','2016-11-23 13:40:14'),(51,'car','driver','varchar','30','司机','select','','user','','','',2,2,2,'1','1','','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(52,'car','mobile','varchar','50','手机','input','','[]','','','',3,3,3,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(53,'car','buyDate','date','','购买日期','date','','{}','','3','',4,4,4,'1','1','','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(54,'car','price','decimal','10,2','价格','decimal','','{}','','','',5,5,5,'1','1','','',0,'0','admin','2020-11-02 10:48:03','admin','2018-08-13 10:04:51'),(55,'car','status','varchar','200','状态','select','','{\"normal\":\"\\u6b63\\u5e38\",\"repairing\":\"\\u7ef4\\u4fee\\u4e2d\",\"broken\":\"\\u635f\\u574f\",\"scrapped\":\"\\u62a5\\u5e9f\"}','normal','','',6,6,6,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(56,'carbooking','id','mediumint','','编号','label','','{}','','2','',9,0,0,'1','1','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(57,'carbooking','parent','mediumint','8','父流程ID','label','','[]','0','','',10,0,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(58,'carbooking','createdBy','varchar','30','由谁创建','select','','user','','','',11,1,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(59,'carbooking','createdDate','datetime','','创建日期','datetime','','[]','','','',12,1,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(60,'carbooking','editedBy','varchar','30','由谁编辑','select','','user','','','',13,0,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(61,'carbooking','editedDate','datetime','','编辑日期','datetime','','[]','','','',14,0,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(62,'carbooking','deleted','varchar','200','是否删除','radio','','[\"\\u672a\\u5220\\u9664\",\"\\u5df2\\u5220\\u9664\"]','0','','',16,0,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(63,'carbooking','appliedBy','varchar','30','申请人','select','','user','','1','',0,1,1,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(64,'carbooking','appliedDate','datetime','','申请时间','datetime','','{}','','1,3','',4,2,2,'1','1','1','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(65,'carbooking','car','varchar','8','车辆','select','','prevModule','','1','',1,3,3,'1','1','','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(66,'carbooking','begin','datetime','','开始时间','datetime','','{}','','1,3','',2,4,4,'1','1','','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(67,'carbooking','end','datetime','','结束时间','datetime','','{}','','1,3','',3,5,5,'1','1','','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(68,'carbooking','reason','varchar','200','理由','input','','{}','','','',6,6,6,'1','1','','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(69,'carbooking','status','varchar','200','状态','select','','{\"wait\":\"\\u7b49\\u5f85\\u5ba1\\u6838\",\"pass\":\"\\u901a\\u8fc7\",\"reject\":\"\\u62d2\\u7edd\"}','wait','1','',5,7,7,'1','1','','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(70,'carbooking','reviewedBy','varchar','30','审核人','select','','user','','','',7,8,8,'1','1','','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(71,'carbooking','reviewedDate','datetime','','审核时间','datetime','','{}','','3','',8,9,9,'1','1','','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(72,'collect','id','mediumint','','编号','label','','{}','','2','',9,0,0,'1','1','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(73,'collect','parent','mediumint','8','父流程ID','label','','[]','0','','',10,1,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(74,'collect','createdBy','varchar','30','由谁创建','select','','user','','','',11,1,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(75,'collect','createdDate','datetime','','创建日期','datetime','','[]','','','',12,1,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(76,'collect','editedBy','varchar','30','由谁编辑','select','','user','','','',13,0,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(77,'collect','editedDate','datetime','','编辑日期','datetime','','[]','','','',14,0,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(78,'collect','deleted','varchar','200','是否删除','radio','','[\"\\u672a\\u5220\\u9664\",\"\\u5df2\\u5220\\u9664\"]','0','','',16,0,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(79,'collect','appliedBy','varchar','30','申请人','select','','user','','1','',0,1,1,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(80,'collect','appliedDate','datetime','','申请时间','datetime','','{}','','1,3','',1,2,2,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(81,'collect','money','decimal','10,2','金额','decimal','','{}','','1','',2,3,3,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','admin','2018-08-13 10:04:16'),(82,'collect','reason','varchar','200','用途','input','','{}','','','',3,4,4,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(83,'collect','status','varchar','200','状态','select','','{\"wait\":\"\\u7b49\\u5f85\\u5ba1\\u6838\",\"pass\":\"\\u901a\\u8fc7\",\"reject\":\"\\u62d2\\u7edd\",\"closed\":\"\\u5df2\\u5b8c\\u6210\"}','wait','','',4,5,5,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','admin','2016-11-23 13:52:21'),(84,'collect','reviewedBy','varchar','30','由谁审核','select','','user','','','',5,6,6,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(85,'collect','reviewedDate','datetime','','审核时间','datetime','','{}','','3','',6,7,7,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(86,'collect','depositor','varchar','200','付款账号','select','','10','','1','',7,8,8,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(87,'collect','category','varchar','200','支出科目','select','','11','','1','',8,9,9,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(88,'buy','id','mediumint','','编号','label','','{}','','2','',8,0,0,'1','1','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(89,'buy','parent','mediumint','8','父流程ID','label','','[]','0','','',9,1,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(90,'buy','createdBy','varchar','30','由谁创建','select','','user','','','',10,1,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(91,'buy','createdDate','datetime','','创建日期','datetime','','{}','','','',11,1,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(92,'buy','editedBy','varchar','30','由谁编辑','select','','user','','','',12,0,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(93,'buy','editedDate','datetime','','编辑日期','datetime','','[]','','','',13,0,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(94,'buy','deleted','varchar','200','是否删除','radio','','[\"\\u672a\\u5220\\u9664\",\"\\u5df2\\u5220\\u9664\"]','0','','',15,0,0,'0','0','0','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(95,'buy','provider','varchar','200','供应商','select','','4','','1','',0,1,1,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(96,'buy','goods','varchar','200','商品','input','','{}','','1','',1,2,2,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(97,'buy','money','decimal','12,2','金额','decimal','','{}','','1','',2,3,3,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','admin','2018-08-13 10:03:37'),(98,'buy','desc','varchar','200','备注','input','','{}','','','',4,4,4,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(99,'buy','status','varchar','200','状态','select','','{\"unpaid\":\"\\u672a\\u652f\\u4ed8\",\"paid\":\"\\u5df2\\u652f\\u4ed8\"}','unpaid','','',3,5,5,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','admin','2020-09-29 10:12:57'),(100,'buy','depositor','varchar','200','付款账号','select','','10','','1','',5,6,6,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(101,'buy','category','varchar','200','支出科目','select','','11','','1','',6,7,7,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(102,'purchasing','id','mediumint','','编号','label','','{}','','2','',6,0,0,'1','1','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(103,'purchasing','parent','mediumint','8','父流程ID','label','','[]','0','','',7,1,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(104,'purchasing','createdBy','varchar','30','由谁创建','select','','user','','','',8,1,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(105,'purchasing','createdDate','datetime','','创建日期','datetime','','[]','','','',9,1,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(106,'purchasing','editedBy','varchar','30','由谁编辑','select','','user','','','',10,1,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(107,'purchasing','editedDate','datetime','','编辑日期','datetime','','[]','','','',11,1,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(108,'purchasing','deleted','enum(\'0\',\'1\')','','是否删除','radio','','[\"\\u672a\\u5220\\u9664\",\"\\u5df2\\u5220\\u9664\"]','0','','',13,0,0,'0','0','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(109,'purchasing','provider','varchar','150','供应商','select','','4','','','',0,1,1,'1','1','','',0,'0','admin','2020-11-02 10:48:03','admin','2019-03-28 14:14:26'),(110,'purchasing','money','decimal','10,2','金额','formula','[{\"type\":\"target\",\"module\":\"purchasegood\",\"field\":\"money\",\"function\":\"sum\",\"text\":\"采购商品_金额_合计值\"}]','[]','','1','',1,2,2,'1','1','0','',0,'0','admin','2020-11-02 10:48:03','admin','2020-10-14 15:18:23'),(111,'purchasing','purchasedby','varchar','30','由谁采购','select','','user','','1','',2,3,3,'1','1','','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(112,'purchasing','purchaseddate','datetime','','采购时间','datetime','','{}','','','',3,4,4,'1','1','','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(113,'purchasing','status','char','30','状态','select','','{\"wait\":\"\\u5f85\\u5ba1\\u6279\",\"pass\":\"\\u5df2\\u901a\\u8fc7\",\"reject\":\"\\u5df2\\u62d2\\u7edd\",\"finished\":\"\\u5df2\\u5b8c\\u6210\"}','wait','','',4,5,5,'1','1','','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(114,'purchasing','desc','varchar','200','描述','input','','{}','','','',5,6,6,'1','1','','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(115,'purchasegood','id','mediumint','8','编号','label','','[]','','2','',5,1,0,'1','','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(116,'purchasegood','parent','varchar','8','父流程ID','label','','[]','','','',6,1,0,'0','','0','',0,'1','admin','2020-11-02 10:48:03','admin','2020-10-29 14:23:07'),(117,'purchasegood','createdBy','varchar','30','由谁创建','select','','user','','','',7,1,0,'0','','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(118,'purchasegood','createdDate','datetime','','创建日期','datetime','','[]','','','',8,1,0,'0','','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(119,'purchasegood','editedBy','varchar','30','由谁编辑','select','','user','','','',9,1,0,'0','','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(120,'purchasegood','editedDate','datetime','','编辑日期','datetime','','[]','','','',10,1,0,'0','','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(121,'purchasegood','deleted','enum(\'0\',\'1\')','','是否删除','radio','','[\"\\u672a\\u5220\\u9664\",\"\\u5df2\\u5220\\u9664\"]','0','','',12,0,0,'0','','','',0,'1','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(123,'purchasegood','product','varchar','200','商品','input','','[]','','1','',0,1,1,'1','','','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(124,'purchasegood','unit','char','20','单位','input','','[]','','','',1,1,2,'1','','','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(125,'purchasegood','price','decimal','12,2','单价','decimal','','[]','','','',2,1,3,'1','','0','',0,'0','admin','2020-11-02 10:48:03','admin','2020-10-14 15:19:40'),(126,'purchasegood','amount','decimal','12,2','数量','decimal','','[]','','','',3,1,4,'1','','0','',0,'0','admin','2020-11-02 10:48:03','admin','2020-10-14 15:19:25'),(127,'purchasegood','money','decimal','12,2','金额','formula','[{\"type\":\"target\",\"module\":\"purchasegood\",\"field\":\"price\",\"text\":\"采购商品_单价\"},{\"type\":\"operator\",\"operator\":\"*\",\"text\":\"×\"},{\"type\":\"target\",\"module\":\"purchasegood\",\"field\":\"amount\",\"text\":\"采购商品_数量\"}]','[]','','','',4,1,5,'1','','0','',0,'0','admin','2020-11-02 10:48:03','admin','2020-10-14 15:19:19'),(132,'buy','files','varchar','255','附件','file','','{}','','','',7,0,0,'0','0','0','',0,'0','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(133,'meetingroom','mailto','text','','抄送给','multi-select','','user','','','',11,0,0,'0','0','0','1',0,'','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(134,'meetingroombooking','mailto','text','','抄送给','multi-select','','user','','','',12,0,0,'0','0','0','1',0,'','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(135,'stamp','mailto','text','','抄送给','multi-select','','user','','','',15,0,0,'0','0','0','1',0,'','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(136,'car','mailto','text','','抄送给','multi-select','','user','','','',13,0,0,'0','0','0','1',0,'','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(137,'carbooking','mailto','text','','抄送给','multi-select','','user','','','',15,0,0,'0','0','0','1',0,'','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(138,'collect','mailto','text','','抄送给','multi-select','','user','','','',15,0,0,'0','0','0','1',0,'','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(139,'buy','mailto','text','','抄送给','multi-select','','user','','','',14,0,0,'0','0','0','1',0,'','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(140,'purchasing','mailto','text','','抄送给','multi-select','','user','','','',12,0,0,'0','0','0','1',0,'','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00'),(141,'purchasegood','mailto','text','','抄送给','multi-select','','user','','','',11,0,0,'0','0','0','1',0,'','admin','2020-11-02 10:48:03','','0000-00-00 00:00:00');
INSERT INTO `sys_workflowlabel` VALUES (1,'meetingroom','label1','所有会议室','[{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"}]','',0,0,'admin','2020-10-14 14:06:14','admin','2016-11-23 10:48:04'),(2,'meetingroombooking','label2','所有预订','[{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"}]','',0,0,'admin','2020-10-14 14:06:14','admin','2016-11-23 11:07:32'),(3,'meetingroom','label3','一楼会议室','[{\"field\":\"position\",\"operator\":\"equal\",\"value\":\"1\"}]','',0,0,'admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(4,'meetingroom','label4','二楼会议室','[{\"field\":\"position\",\"operator\":\"equal\",\"value\":\"2\"}]','',0,0,'admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(5,'meetingroom','label5','三楼会议室','[{\"field\":\"position\",\"operator\":\"equal\",\"value\":\"3\"}]','',0,0,'admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(6,'meetingroombooking','label6','我的预订','[{\"field\":\"orderedBy\",\"operator\":\"equal\",\"value\":\"currentUser\"}]','',0,0,'admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(7,'stamp','label7','所有','[{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"}]','',0,0,'admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(8,'car','label8','车辆列表','[{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"}]','',0,0,'admin','2020-10-14 14:06:14','admin','2016-11-23 13:28:10'),(9,'carbooking','label9','所有预订','[{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"}]','',0,0,'admin','2020-10-14 14:06:14','admin','2016-11-23 13:29:07'),(10,'stamp','label10','我的申请','[{\"field\":\"proposer\",\"operator\":\"equal\",\"value\":\"currentUser\"},{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"}]','',0,0,'admin','2020-10-14 14:06:14','admin','2016-11-23 13:27:26'),(11,'stamp','label11','我的审核','[{\"field\":\"status\",\"operator\":\"equal\",\"value\":\"wait\"},{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"}]','',0,0,'admin','2020-10-14 14:06:14','admin','2016-11-24 13:56:12'),(12,'carbooking','label12','我的预订','[{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"},{\"field\":\"appliedBy\",\"operator\":\"equal\",\"value\":\"currentUser\"}]','',0,0,'admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(13,'carbooking','label13','我的审核','[{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"},{\"field\":\"status\",\"operator\":\"equal\",\"value\":\"wait\"}]','',0,0,'admin','2020-10-14 14:06:14','admin','2016-11-24 13:56:46'),(14,'collect','label14','所有','[{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"}]','',0,0,'admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(15,'collect','label15','我的请款','[{\"field\":\"appliedBy\",\"operator\":\"equal\",\"value\":\"currentUser\"},{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"}]','',0,0,'admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(16,'collect','label16','我的审核','[{\"field\":\"status\",\"operator\":\"equal\",\"value\":\"wait\"},{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"}]','',0,0,'admin','2020-10-14 14:06:14','admin','2016-11-24 14:02:10'),(17,'collect','label17','待付款','[{\"field\":\"status\",\"operator\":\"equal\",\"value\":\"pass\"},{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"}]','',0,0,'admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(18,'buy','label18','所有','[{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"}]','',0,0,'admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(19,'buy','label19','待付款','[{\"field\":\"status\",\"operator\":\"equal\",\"value\":\"unpaid\"},{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"}]','',0,0,'admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(20,'buy','label20','已付款','[{\"field\":\"status\",\"operator\":\"equal\",\"value\":\"paid\"},{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"}]','',0,0,'admin','2020-10-14 14:06:14','admin','2016-11-23 14:22:20'),(21,'purchasing','label21','所有','[{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"}]','',0,0,'admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(22,'purchasegood','label22','所有','[{\"field\":\"deleted\",\"operator\":\"equal\",\"value\":\"0\"}]','',0,0,'admin','2020-10-14 14:06:14','','0000-00-00 00:00:00');
INSERT INTO `sys_workflowlayout` VALUES (1332,'meetingroom','browse','position',3,0,'left','0','0','','',''),(1333,'meetingroom','browse','seats',4,0,'left','0','0','','',''),(887,'meetingroom','create','equipment',4,0,'','0','0','','',''),(886,'meetingroom','create','seats',3,0,'','0','0','','',''),(885,'meetingroom','create','position',2,0,'','0','0','','',''),(884,'meetingroom','create','name',1,0,'','0','0','','',''),(892,'meetingroom','edit','equipment',4,0,'','0','0','','',''),(891,'meetingroom','edit','seats',3,0,'','0','0','','',''),(890,'meetingroom','edit','position',2,0,'','0','0','','',''),(889,'meetingroom','edit','name',1,0,'','0','0','','',''),(20,'meetingroom','view','id',1,0,'basic','0','0','','',''),(21,'meetingroom','view','name',2,0,'basic','0','0','','',''),(22,'meetingroom','view','position',3,0,'basic','0','0','','',''),(23,'meetingroom','view','seats',4,0,'basic','0','0','','',''),(24,'meetingroom','view','equipment',5,0,'basic','0','0','','',''),(25,'meetingroom','view','workday',6,0,'basic','0','0','','',''),(26,'meetingroom','view','createdBy',7,0,'basic','0','0','','',''),(27,'meetingroom','view','createdDate',8,0,'basic','0','0','','',''),(28,'meetingroom','view','editedBy',9,0,'basic','0','0','','',''),(29,'meetingroom','view','editedDate',10,0,'basic','0','0','','',''),(1283,'meetingroombooking','browse','orderedBy',5,100,'left','0','0','','',''),(1284,'meetingroombooking','browse','orderedDate',6,100,'left','0','0','','',''),(1279,'meetingroombooking','browse','id',1,80,'left','0','0','','',''),(1280,'meetingroombooking','browse','room',2,160,'left','0','0','','',''),(932,'meetingroombooking','create','orderedBy',4,0,'','0','0','','currentUser',''),(933,'meetingroombooking','create','orderedDate',5,0,'','0','0','','currentTime',''),(929,'meetingroombooking','create','room',1,0,'','0','0','','',''),(930,'meetingroombooking','create','begin',2,0,'','0','0','','',''),(931,'meetingroombooking','create','end',3,0,'','0','0','','',''),(50,'meetingroombooking','edit','room',1,0,'','0','0','','',''),(51,'meetingroombooking','edit','begin',2,0,'','0','0','','',''),(52,'meetingroombooking','edit','end',3,0,'','0','0','','',''),(53,'meetingroombooking','edit','orderedBy',4,0,'','0','0','','currentUser',''),(54,'meetingroombooking','edit','orderedDate',5,0,'','0','0','','currentTime',''),(55,'meetingroombooking','edit','desc',6,0,'','0','0','','',''),(74,'meetingroombooking','view','createdDate',8,0,'basic','0','0','','',''),(73,'meetingroombooking','view','createdBy',7,0,'basic','0','0','','',''),(72,'meetingroombooking','view','orderedDate',6,0,'basic','0','0','','',''),(71,'meetingroombooking','view','orderedBy',5,0,'basic','0','0','','',''),(70,'meetingroombooking','view','end',4,0,'basic','0','0','','',''),(69,'meetingroombooking','view','begin',3,0,'basic','0','0','','',''),(68,'meetingroombooking','view','room',2,0,'basic','0','0','','',''),(67,'meetingroombooking','view','id',1,0,'basic','0','0','','',''),(75,'meetingroombooking','view','editedBy',9,0,'basic','0','0','','',''),(76,'meetingroombooking','view','editedDate',10,0,'basic','0','0','','',''),(77,'meetingroombooking','view','desc',11,0,'info','0','0','','',''),(847,'stamp','browse','id',1,0,'left','0','0','','',''),(856,'stamp','browse','reviewedDate',10,0,'left','0','0','','',''),(848,'stamp','browse','proposer',2,0,'left','0','0','','',''),(849,'stamp','browse','reason',3,0,'left','0','0','','',''),(850,'stamp','browse','begin',4,0,'left','0','0','','',''),(851,'stamp','browse','end',5,0,'left','0','0','','',''),(852,'stamp','browse','type',6,0,'left','0','0','','',''),(1290,'stamp','create','end',4,0,'','0','0','','',''),(1288,'stamp','create','reason',2,0,'','0','0','','',''),(1289,'stamp','create','begin',3,0,'','0','0','','',''),(113,'stamp','edit','end',4,0,'','0','0','','',''),(112,'stamp','edit','begin',3,0,'','0','0','','',''),(111,'stamp','edit','reason',2,0,'','0','0','','',''),(110,'stamp','edit','proposer',1,0,'','0','0','','currentUser',''),(114,'stamp','edit','type',5,0,'','0','0','','',''),(115,'stamp','edit','desc',6,0,'','0','0','','',''),(877,'stamp','view','status',8,0,'basic','0','0','','',''),(876,'stamp','view','desc',7,0,'info','0','0','','',''),(875,'stamp','view','type',6,0,'basic','0','0','','',''),(870,'stamp','view','id',1,0,'basic','0','0','','',''),(871,'stamp','view','proposer',2,0,'basic','0','0','','',''),(872,'stamp','view','reason',3,0,'info','0','0','','',''),(873,'stamp','view','begin',4,0,'basic','0','0','','',''),(874,'stamp','view','end',5,0,'basic','0','0','','',''),(878,'stamp','view','reviewedBy',9,0,'basic','0','0','','',''),(998,'car','browse','actions',9,170,'','0','0','','',''),(993,'car','browse','driver',4,0,'left','0','0','','',''),(992,'car','browse','code',3,0,'left','0','0','','',''),(1343,'car','create','type',1,0,'','0','0','','',''),(1346,'car','create','mobile',4,0,'','0','0','','',''),(1347,'car','create','buyDate',5,0,'','0','0','','',''),(146,'car','edit','type',1,0,'','0','0','','',''),(147,'car','edit','code',2,0,'','0','0','','',''),(148,'car','edit','driver',3,0,'','0','0','','',''),(149,'car','edit','mobile',4,0,'','0','0','','',''),(150,'car','edit','buyDate',5,0,'','0','0','','',''),(151,'car','edit','price',6,0,'','0','0','','',''),(152,'car','edit','status',7,0,'','0','0','','',''),(153,'car','view','id',1,0,'basic','0','0','','',''),(154,'car','view','type',2,0,'basic','0','0','','',''),(155,'car','view','code',3,0,'basic','0','0','','',''),(156,'car','view','driver',4,0,'basic','0','0','','',''),(157,'car','view','mobile',5,0,'basic','0','0','','',''),(158,'car','view','buyDate',6,0,'basic','0','0','','',''),(159,'car','view','price',7,0,'basic','0','0','','',''),(160,'car','view','status',8,0,'basic','0','0','','',''),(161,'car','view','createdBy',9,0,'basic','0','0','','',''),(162,'car','view','createdDate',10,0,'basic','0','0','','',''),(163,'car','view','editedBy',11,0,'basic','0','0','','',''),(164,'car','view','editedDate',12,0,'basic','0','0','','',''),(1019,'carbooking','browse','reviewedDate',10,0,'left','0','0','','',''),(1013,'carbooking','browse','begin',4,0,'left','0','0','','',''),(1014,'carbooking','browse','end',5,0,'left','0','0','','',''),(1015,'carbooking','browse','reason',6,0,'left','0','0','','',''),(1016,'carbooking','browse','status',7,0,'left','0','0','','',''),(1017,'carbooking','browse','appliedDate',8,0,'left','0','0','','',''),(977,'carbooking','create','car',3,0,'','0','0','','',''),(978,'carbooking','create','begin',4,0,'','0','0','','',''),(976,'carbooking','create','appliedDate',2,0,'','0','0','','currentTime',''),(975,'carbooking','create','appliedBy',1,0,'','0','0','','currentUser',''),(188,'carbooking','edit','appliedBy',1,0,'','0','0','','currentUser',''),(189,'carbooking','edit','appliedDate',2,0,'','0','0','','currentTime',''),(190,'carbooking','edit','car',3,0,'','0','0','','',''),(191,'carbooking','edit','begin',4,0,'','0','0','','',''),(192,'carbooking','edit','end',5,0,'','0','0','','',''),(193,'carbooking','edit','reason',6,0,'','0','0','','',''),(194,'carbooking','view','id',1,0,'basic','0','0','','',''),(195,'carbooking','view','appliedBy',2,0,'basic','0','0','','',''),(196,'carbooking','view','appliedDate',3,0,'basic','0','0','','',''),(197,'carbooking','view','car',4,0,'basic','0','0','','',''),(198,'carbooking','view','begin',5,0,'basic','0','0','','',''),(199,'carbooking','view','end',6,0,'basic','0','0','','',''),(200,'carbooking','view','reason',7,0,'info','0','0','','',''),(201,'carbooking','view','status',8,0,'basic','0','0','','',''),(202,'carbooking','view','reviewedBy',9,0,'basic','0','0','','',''),(203,'carbooking','view','reviewedDate',10,0,'basic','0','0','','',''),(204,'carbooking','view','createdBy',11,0,'basic','0','0','','',''),(205,'carbooking','view','createdDate',12,0,'basic','0','0','','',''),(206,'carbooking','view','editedBy',13,0,'basic','0','0','','',''),(207,'carbooking','view','editedDate',14,0,'basic','0','0','','',''),(994,'car','browse','mobile',5,0,'left','0','0','','',''),(1018,'carbooking','browse','reviewedBy',9,0,'left','0','0','','',''),(1010,'carbooking','browse','id',1,0,'left','0','0','','',''),(1073,'collect','browse','actions',9,230,'','0','0','','',''),(1068,'collect','browse','reason',4,0,'left','0','0','','',''),(1066,'collect','browse','appliedBy',2,0,'left','0','0','','',''),(1067,'collect','browse','money',3,0,'left','0','0','','',''),(1064,'collect','create','reason',4,0,'','0','0','','',''),(1062,'collect','create','appliedDate',2,0,'','0','0','','currentTime',''),(261,'collect','edit','appliedDate',2,0,'','0','0','','currentTime',''),(260,'collect','edit','appliedBy',1,0,'','0','0','','currentUser',''),(1063,'collect','create','money',3,0,'','0','0','','',''),(262,'collect','edit','money',3,0,'','0','0','','',''),(263,'collect','edit','reason',4,0,'','0','0','','',''),(264,'collect','view','id',1,0,'basic','0','0','','',''),(265,'collect','view','appliedBy',2,0,'basic','0','0','','',''),(266,'collect','view','appliedDate',3,0,'basic','0','0','','',''),(267,'collect','view','money',4,0,'basic','0','0','','',''),(268,'collect','view','reason',5,0,'info','0','0','','',''),(269,'collect','view','status',6,0,'basic','0','0','','',''),(270,'collect','view','reviewedBy',7,0,'basic','0','0','','',''),(271,'collect','view','reviewedDate',8,0,'basic','0','0','','',''),(272,'collect','view','createdBy',9,0,'basic','0','0','','',''),(273,'collect','view','createdDate',10,0,'basic','0','0','','',''),(274,'collect','view','editedBy',11,0,'basic','0','0','','',''),(275,'collect','view','editedDate',12,0,'basic','0','0','','',''),(276,'collect','pay','depositor',1,0,'','0','0','','',''),(277,'collect','pay','category',2,0,'','0','0','','',''),(1071,'collect','browse','reviewedBy',7,0,'left','0','0','','',''),(1072,'collect','browse','reviewedDate',8,0,'left','0','0','','',''),(1126,'buy','browse','provider',2,0,'left','0','0','','',''),(1127,'buy','browse','goods',3,0,'left','0','0','','',''),(1128,'buy','browse','money',4,0,'left','0','0','','',''),(1129,'buy','browse','desc',5,0,'left','0','0','','',''),(1130,'buy','browse','status',6,0,'left','0','0','','',''),(1131,'buy','browse','createdBy',7,0,'left','0','0','','',''),(1310,'buy','create','money',3,0,'','0','0','','',''),(1308,'buy','create','provider',1,0,'','0','0','','',''),(1091,'buy','edit','money',3,0,'','0','0','','',''),(1089,'buy','edit','provider',1,0,'','0','0','','',''),(1312,'buy','create','files',5,0,'','0','0','','',''),(1309,'buy','create','goods',2,0,'','0','0','','',''),(1093,'buy','edit','files',5,0,'','0','0','','',''),(1090,'buy','edit','goods',2,0,'','0','0','','',''),(1105,'buy','view','id',1,0,'basic','0','0','','',''),(1106,'buy','view','provider',2,0,'basic','0','0','','',''),(1107,'buy','view','goods',3,0,'basic','0','0','','',''),(1108,'buy','view','money',4,0,'basic','0','0','','',''),(1109,'buy','view','status',5,0,'basic','0','0','','',''),(1110,'buy','view','createdBy',6,0,'basic','0','0','','',''),(1111,'buy','view','createdDate',7,0,'basic','0','0','','',''),(1112,'buy','view','editedBy',8,0,'basic','0','0','','',''),(343,'buy','pay','depositor',1,0,'','0','0','','',''),(344,'buy','pay','category',2,0,'','0','0','','',''),(1178,'purchasing','create','sub_purchasegood',2,0,'','0','0','','',''),(1313,'purchasing','create','provider',1,0,'','0','0','','',''),(1319,'purchasing','edit','money',2,0,'','0','0','','',''),(1167,'purchasing','edit','sub_purchasegood',2,0,'','0','0','','',''),(1244,'purchasing','view','editedBy',9,0,'basic','0','0','','',''),(1241,'purchasing','view','sub_purchasegood',6,0,'info','0','0','','',''),(1239,'purchasing','view','purchasedby',4,0,'basic','0','0','','',''),(1240,'purchasing','view','purchaseddate',5,0,'basic','0','0','','',''),(1271,'purchasing','browse','id',1,80,'left','0','0','','',''),(1272,'purchasing','browse','provider',2,200,'left','0','0','','',''),(1273,'purchasing','browse','money',3,160,'right','0','0','','',''),(1274,'purchasing','browse','purchasedby',4,120,'center','0','0','','',''),(1275,'purchasing','browse','purchaseddate',5,120,'center','0','0','','',''),(1186,'purchasegood','create','amount',4,0,'','0','0','','',''),(1184,'purchasegood','create','unit',2,0,'','0','0','','',''),(1183,'purchasegood','create','product',1,0,'','0','0','','',''),(1185,'purchasegood','create','price',3,0,'','0','0','','',''),(1320,'purchasing','edit','purchasedby',3,0,'','0','0','','',''),(1176,'purchasegood','edit','money',5,0,'','0','0','','',''),(1172,'purchasegood','edit','product',1,0,'','0','0','','',''),(1173,'purchasegood','edit','unit',2,0,'','0','0','','',''),(1174,'purchasegood','edit','price',3,0,'','0','0','','',''),(1175,'purchasegood','edit','amount',4,0,'','0','0','','',''),(1236,'purchasing','view','provider',1,0,'basic','0','0','','',''),(1237,'purchasing','view','money',2,0,'basic','0','0','','',''),(1238,'purchasing','view','status',3,0,'basic','0','0','','',''),(1247,'purchasegood','view','id',1,80,'','0','1','','',''),(1248,'purchasegood','view','product',2,0,'','0','1','','',''),(1276,'purchasing','browse','status',6,120,'center','0','0','','',''),(1243,'purchasing','view','createdDate',8,0,'basic','0','0','','',''),(1242,'purchasing','view','createdBy',7,0,'basic','0','0','','',''),(1250,'purchasegood','view','price',4,100,'','0','1','','',''),(1249,'purchasegood','view','unit',3,100,'','0','1','','',''),(820,'purchasing','batchcreate','provider',1,300,'','0','0','','',''),(821,'purchasing','batchcreate','money',2,200,'','0','0','','',''),(822,'purchasing','batchcreate','purchasedby',3,120,'','0','0','','',''),(825,'purchasing','batchedit','provider',1,300,'','0','0','','',''),(826,'purchasing','batchedit','money',2,200,'','0','0','','',''),(827,'purchasing','batchedit','purchasedby',3,120,'','0','0','','',''),(814,'buy','batchcreate','money',3,200,'','0','0','','',''),(812,'buy','batchcreate','provider',1,300,'','0','0','','',''),(817,'buy','batchedit','goods',2,300,'','0','0','','',''),(816,'buy','batchedit','provider',1,300,'','0','0','','',''),(800,'collect','batchcreate','appliedBy',1,120,'','0','0','','',''),(801,'collect','batchcreate','appliedDate',2,150,'','0','0','','',''),(802,'collect','batchcreate','money',3,200,'','0','0','','',''),(828,'purchasing','batchedit','purchaseddate',4,150,'','0','0','','',''),(823,'purchasing','batchcreate','purchaseddate',4,150,'','0','0','','',''),(804,'collect','batchedit','appliedBy',1,120,'','0','0','','',''),(805,'collect','batchedit','appliedDate',2,150,'','0','0','','',''),(791,'carbooking','batchcreate','begin',4,150,'','0','0','','',''),(790,'carbooking','batchcreate','car',3,150,'','0','0','','',''),(789,'carbooking','batchcreate','appliedDate',2,150,'','0','0','','',''),(788,'carbooking','batchcreate','appliedBy',1,120,'','0','0','','',''),(797,'carbooking','batchedit','begin',4,150,'','0','0','','',''),(796,'carbooking','batchedit','car',3,150,'','0','0','','',''),(795,'carbooking','batchedit','appliedDate',2,150,'','0','0','','',''),(794,'carbooking','batchedit','appliedBy',1,120,'','0','0','','',''),(1337,'car','batchcreate','type',1,150,'','0','0','','',''),(1341,'car','batchcreate','buyDate',5,120,'','0','0','','',''),(1340,'car','batchcreate','mobile',4,0,'','0','0','','',''),(763,'car','batchedit','type',1,150,'','0','0','','',''),(764,'car','batchedit','code',2,0,'','0','0','','',''),(765,'car','batchedit','driver',3,120,'','0','0','','',''),(766,'car','batchedit','mobile',4,0,'','0','0','','',''),(767,'car','batchedit','buyDate',5,120,'','0','0','','',''),(860,'stamp','batchcreate','begin',3,150,'','0','0','','',''),(861,'stamp','batchcreate','end',4,150,'','0','0','','',''),(867,'stamp','batchedit','end',4,150,'','0','0','','',''),(865,'stamp','batchedit','reason',2,0,'','0','0','','',''),(866,'stamp','batchedit','begin',3,150,'','0','0','','',''),(711,'meetingroombooking','batchcreate','room',1,200,'','0','0','','',''),(712,'meetingroombooking','batchcreate','begin',2,150,'','0','0','','',''),(713,'meetingroombooking','batchcreate','end',3,150,'','0','0','','',''),(714,'meetingroombooking','batchcreate','orderedBy',4,120,'','0','0','','',''),(715,'meetingroombooking','batchcreate','orderedDate',5,150,'','0','0','','',''),(717,'meetingroombooking','batchedit','room',1,200,'','0','0','','',''),(718,'meetingroombooking','batchedit','begin',2,150,'','0','0','','',''),(719,'meetingroombooking','batchedit','end',3,150,'','0','0','','',''),(720,'meetingroombooking','batchedit','orderedBy',4,120,'','0','0','','',''),(690,'meetingroom','batchcreate','name',1,0,'','0','0','','',''),(691,'meetingroom','batchcreate','position',2,100,'','0','0','','',''),(692,'meetingroom','batchcreate','seats',3,100,'','0','0','','',''),(693,'meetingroom','batchcreate','equipment',4,320,'','0','0','','',''),(698,'meetingroom','batchedit','equipment',4,320,'','0','0','','',''),(696,'meetingroom','batchedit','position',2,100,'','0','0','','',''),(697,'meetingroom','batchedit','seats',3,100,'','0','0','','',''),(695,'meetingroom','batchedit','name',1,0,'','0','0','','',''),(694,'meetingroom','batchcreate','workday',5,400,'','0','0','','',''),(699,'meetingroom','batchedit','workday',5,400,'','0','0','','',''),(716,'meetingroombooking','batchcreate','desc',6,0,'','0','0','','',''),(721,'meetingroombooking','batchedit','orderedDate',5,150,'','0','0','','',''),(722,'meetingroombooking','batchedit','desc',6,0,'','0','0','','',''),(858,'stamp','batchcreate','proposer',1,120,'','0','0','','',''),(859,'stamp','batchcreate','reason',2,0,'','0','0','','',''),(864,'stamp','batchedit','proposer',1,120,'','0','0','','',''),(1338,'car','batchcreate','code',2,0,'','0','0','','',''),(1339,'car','batchcreate','driver',3,120,'','0','0','','',''),(769,'car','batchedit','status',7,120,'','0','0','','normal',''),(768,'car','batchedit','price',6,0,'','0','0','','',''),(996,'car','browse','price',7,0,'left','0','0','','',''),(991,'car','browse','type',2,0,'left','0','0','','',''),(792,'carbooking','batchcreate','end',5,150,'','0','0','','',''),(793,'carbooking','batchcreate','reason',6,0,'','0','0','','',''),(798,'carbooking','batchedit','end',5,150,'','0','0','','',''),(799,'carbooking','batchedit','reason',6,0,'','0','0','','',''),(803,'collect','batchcreate','reason',4,0,'','0','0','','',''),(806,'collect','batchedit','money',3,200,'','0','0','','',''),(807,'collect','batchedit','reason',4,0,'','0','0','','',''),(813,'buy','batchcreate','goods',2,300,'','0','0','','',''),(815,'buy','batchcreate','desc',4,0,'','0','0','','',''),(818,'buy','batchedit','money',3,200,'','0','0','','',''),(819,'buy','batchedit','desc',4,0,'','0','0','','',''),(824,'purchasing','batchcreate','desc',5,0,'','0','0','','',''),(829,'purchasing','batchedit','desc',5,0,'','0','0','','',''),(1245,'purchasing','view','editedDate',10,0,'basic','0','0','','',''),(1287,'stamp','create','proposer',1,0,'','0','0','','currentUser',''),(857,'stamp','browse','actions',11,280,'','0','0','','',''),(853,'stamp','browse','desc',7,0,'left','0','0','','',''),(854,'stamp','browse','status',8,0,'left','0','0','','',''),(855,'stamp','browse','reviewedBy',9,0,'left','0','0','','',''),(862,'stamp','batchcreate','type',5,350,'','0','0','','',''),(863,'stamp','batchcreate','desc',6,0,'','0','0','','',''),(868,'stamp','batchedit','type',5,350,'','0','0','','',''),(869,'stamp','batchedit','desc',6,0,'','0','0','','',''),(879,'stamp','view','reviewedDate',10,0,'basic','0','0','','',''),(880,'stamp','view','createdBy',11,0,'basic','0','0','','',''),(881,'stamp','view','createdDate',12,0,'basic','0','0','','',''),(882,'stamp','view','editedBy',13,0,'basic','0','0','','',''),(883,'stamp','view','editedDate',14,0,'basic','0','0','','',''),(888,'meetingroom','create','workday',5,0,'','0','0','','',''),(893,'meetingroom','edit','workday',5,0,'','0','0','','',''),(1335,'meetingroom','browse','workday',6,0,'left','0','0','','',''),(1334,'meetingroom','browse','equipment',5,0,'left','0','0','','',''),(934,'meetingroombooking','create','desc',6,0,'','0','0','','',''),(1281,'meetingroombooking','browse','begin',3,120,'left','0','0','','',''),(1282,'meetingroombooking','browse','end',4,120,'left','0','0','','',''),(1345,'car','create','driver',3,0,'','0','0','','',''),(1344,'car','create','code',2,0,'','0','0','','',''),(997,'car','browse','status',8,0,'left','0','0','','',''),(995,'car','browse','buyDate',6,0,'left','0','0','','',''),(990,'car','browse','id',1,0,'left','0','0','','',''),(979,'carbooking','create','end',5,0,'','0','0','','',''),(980,'carbooking','create','reason',6,0,'','0','0','','',''),(1011,'carbooking','browse','appliedBy',2,0,'left','0','0','','',''),(1012,'carbooking','browse','car',3,0,'left','0','0','','',''),(1020,'carbooking','browse','actions',11,200,'','0','0','','',''),(1061,'collect','create','appliedBy',1,0,'','0','0','','currentUser',''),(1070,'collect','browse','appliedDate',6,0,'left','0','0','','',''),(1069,'collect','browse','status',5,0,'left','0','0','','',''),(1065,'collect','browse','id',1,0,'left','0','0','','',''),(1311,'buy','create','desc',4,0,'','0','0','','',''),(1092,'buy','edit','desc',4,0,'','0','0','','',''),(1125,'buy','browse','id',1,0,'left','0','0','','',''),(1115,'buy','view','files',11,0,'info','0','0','','',''),(1114,'buy','view','desc',10,0,'info','0','0','','',''),(1113,'buy','view','editedDate',9,0,'basic','0','0','','',''),(1133,'buy','browse','actions',9,170,'','0','0','','',''),(1132,'buy','browse','createdDate',8,0,'left','0','0','','',''),(1316,'purchasing','create','purchaseddate',4,0,'','0','0','','',''),(1318,'purchasing','edit','provider',1,0,'','0','0','','',''),(1277,'purchasing','browse','desc',7,0,'left','0','0','','',''),(1278,'purchasing','browse','actions',8,200,'','0','0','','',''),(1314,'purchasing','create','money',2,0,'','0','0','','',''),(1187,'purchasegood','create','money',5,0,'','0','0','','',''),(1246,'purchasing','view','desc',11,0,'info','0','0','','',''),(1251,'purchasegood','view','amount',5,100,'','0','1','','',''),(1252,'purchasegood','view','money',6,100,'','0','1','','',''),(1321,'purchasing','edit','purchaseddate',4,0,'','0','0','','',''),(1285,'meetingroombooking','browse','desc',7,0,'left','0','0','','',''),(1286,'meetingroombooking','browse','actions',8,140,'','0','0','','',''),(1291,'stamp','create','type',5,0,'','0','0','','',''),(1292,'stamp','create','desc',6,0,'','0','0','','',''),(1315,'purchasing','create','purchasedby',3,0,'','0','0','','',''),(1317,'purchasing','create','desc',5,0,'','0','0','','',''),(1322,'purchasing','edit','desc',5,0,'','0','0','','',''),(1330,'meetingroom','browse','id',1,0,'left','0','0','','',''),(1331,'meetingroom','browse','name',2,0,'left','0','0','','',''),(1336,'meetingroom','browse','actions',7,170,'','0','0','','',''),(1342,'car','batchcreate','price',6,0,'','0','0','','',''),(1348,'car','create','price',6,0,'','0','0','','',''),(1349,'car','create','status',7,0,'','0','0','','normal','');
INSERT INTO `sys_workflowrelation` VALUES (3,'meetingroom','meetingroombooking','room','one2one,many2many','admin','2020-09-28 16:47:52'),(4,'car','carbooking','car','one2one,many2many','admin','2020-09-28 17:06:18');
INSERT INTO `sys_workflowrule` VALUES (1,'system','必填','notempty','admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(2,'system','唯一','unique','admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(3,'system','日期','date','admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(4,'system','email','email','admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(5,'system','数字','float','admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(6,'system','电话','phone','admin','2020-10-14 14:06:14','','0000-00-00 00:00:00'),(7,'system','IP','ip','admin','2020-10-14 14:06:14','','0000-00-00 00:00:00');

REPLACE INTO `sys_grouppriv` VALUES
(1,'apppriv','flow'),
(1,'workflow','activate'),
(1,'workflow','backup'),
(1,'workflow','browseDB'),
(1,'workflow','browseFlow'),
(1,'workflow','copy'),
(1,'workflow','create'),
(1,'workflow','css'),
(1,'workflow','deactivate'),
(1,'workflow','delete'),
(1,'workflow','edit'),
(1,'workflow','flowchart'),
(1,'workflow','js'),
(1,'workflow','release'),
(1,'workflow','ui'),
(1,'workflow','upgrade'),
(1,'workflow','view'),
(1,'workflowaction','browse'),
(1,'workflowaction','create'),
(1,'workflowaction','css'),
(1,'workflowaction','delete'),
(1,'workflowaction','edit'),
(1,'workflowaction','js'),
(1,'workflowaction','setNotice'),
(1,'workflowaction','setVerification'),
(1,'workflowaction','sort'),
(1,'workflowaction','view'),
(1,'workflowcondition','browse'),
(1,'workflowcondition','create'),
(1,'workflowcondition','delete'),
(1,'workflowcondition','edit'),
(1,'workflowdatasource','browse'),
(1,'workflowdatasource','create'),
(1,'workflowdatasource','delete'),
(1,'workflowdatasource','edit'),
(1,'workflowfield','browse'),
(1,'workflowfield','create'),
(1,'workflowfield','delete'),
(1,'workflowfield','edit'),
(1,'workflowfield','setValue'),
(1,'workflowfield','setExport'),
(1,'workflowfield','setSearch'),
(1,'workflowfield','sort'),
(1,'workflowhook','browse'),
(1,'workflowhook','create'),
(1,'workflowhook','delete'),
(1,'workflowhook','edit'),
(1,'workflowlabel','browse'),
(1,'workflowlabel','create'),
(1,'workflowlabel','delete'),
(1,'workflowlabel','edit'),
(1,'workflowlabel','sort'),
(1,'workflowlayout','admin'),
(1,'workflowlinkage','browse'),
(1,'workflowlinkage','create'),
(1,'workflowlinkage','delete'),
(1,'workflowlinkage','edit'),
(1,'workflowrelation','admin'),
(1,'workflowrule','browse'),
(1,'workflowrule','create'),
(1,'workflowrule','delete'),
(1,'workflowrule','edit'),
(1,'workflowrule','view');

-- DROP TABLE IF EXISTS `flow_buy`;
CREATE TABLE IF NOT EXISTS `flow_buy` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `provider` varchar(200) NOT NULL,
  `goods` varchar(200) NOT NULL,
  `money` decimal(12,2) NOT NULL,
  `desc` varchar(200) NOT NULL,
  `status` varchar(200) NOT NULL DEFAULT 'unpaid',
  `depositor` varchar(200) NOT NULL,
  `category` varchar(200) NOT NULL,
  `parent` mediumint(8) unsigned NOT NULL,
  `createdBy` varchar(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  `editedBy` varchar(30) NOT NULL,
  `editedDate` datetime NOT NULL,
  `mailto` text NOT NULL,
  `deleted` enum('0','1') NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `flow_car`;
CREATE TABLE IF NOT EXISTS `flow_car` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `type` varchar(200) NOT NULL,
  `code` varchar(200) NOT NULL,
  `driver` varchar(200) NOT NULL,
  `mobile` varchar(50) NOT NULL,
  `buyDate` date NOT NULL,
  `price` decimal(12,2) NOT NULL,
  `status` varchar(200) NOT NULL DEFAULT 'normal',
  `parent` mediumint(8) unsigned NOT NULL,
  `createdBy` varchar(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  `editedBy` varchar(30) NOT NULL,
  `editedDate` datetime NOT NULL,
  `mailto` text NOT NULL,
  `deleted` enum('0','1') NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `flow_carbooking`;
CREATE TABLE IF NOT EXISTS `flow_carbooking` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `appliedBy` varchar(200) NOT NULL,
  `appliedDate` datetime NOT NULL,
  `car` varchar(200) NOT NULL,
  `begin` datetime NOT NULL,
  `end` datetime NOT NULL,
  `reason` varchar(200) NOT NULL,
  `status` varchar(200) NOT NULL DEFAULT 'wait',
  `reviewedBy` varchar(200) NOT NULL,
  `reviewedDate` datetime NOT NULL,
  `parent` mediumint(8) unsigned NOT NULL,
  `createdBy` varchar(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  `editedBy` varchar(30) NOT NULL,
  `editedDate` datetime NOT NULL,
  `mailto` text NOT NULL,
  `deleted` enum('0','1') NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `flow_collect`;
CREATE TABLE IF NOT EXISTS `flow_collect` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `appliedBy` varchar(200) NOT NULL,
  `appliedDate` datetime NOT NULL,
  `money` decimal(12,2) NOT NULL,
  `reason` varchar(200) NOT NULL,
  `status` varchar(200) NOT NULL DEFAULT 'wait',
  `reviewedBy` varchar(200) NOT NULL,
  `reviewedDate` datetime NOT NULL,
  `depositor` varchar(200) NOT NULL,
  `category` varchar(200) NOT NULL,
  `parent` mediumint(8) unsigned NOT NULL,
  `createdBy` varchar(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  `editedBy` varchar(30) NOT NULL,
  `editedDate` datetime NOT NULL,
  `mailto` text NOT NULL,
  `deleted` enum('0','1') NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `flow_meetingroom`;
CREATE TABLE IF NOT EXISTS `flow_meetingroom` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(200) NOT NULL,
  `position` varchar(200) NOT NULL,
  `seats` smallint(6) NOT NULL,
  `equipment` varchar(200) NOT NULL,
  `workday` varchar(200) NOT NULL,
  `parent` mediumint(8) unsigned NOT NULL,
  `createdBy` varchar(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  `editedBy` varchar(30) NOT NULL,
  `editedDate` datetime NOT NULL,
  `mailto` text NOT NULL,
  `deleted` enum('0','1') NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `flow_meetingroombooking`;
CREATE TABLE IF NOT EXISTS `flow_meetingroombooking` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `room` varchar(200) NOT NULL,
  `begin` datetime NOT NULL,
  `end` datetime NOT NULL,
  `orderedBy` varchar(200) NOT NULL,
  `orderedDate` datetime NOT NULL,
  `desc` varchar(200) NOT NULL,
  `parent` mediumint(8) unsigned NOT NULL,
  `createdBy` varchar(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  `editedBy` varchar(30) NOT NULL,
  `editedDate` datetime NOT NULL,
  `mailto` text NOT NULL,
  `deleted` enum('0','1') NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `flow_purchasegood`;
CREATE TABLE IF NOT EXISTS `flow_purchasegood` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `product` varchar(200) NOT NULL,
  `unit` char(20) NOT NULL,
  `price` decimal(12,2) NOT NULL,
  `amount` decimal(12,2) NOT NULL,
  `money` decimal(12,2) NOT NULL,
  `parent` mediumint(8) unsigned NOT NULL,
  `createdBy` varchar(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  `editedBy` varchar(30) NOT NULL,
  `editedDate` datetime NOT NULL,
  `mailto` text NOT NULL,
  `deleted` enum('0','1') NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `flow_purchasing`;
CREATE TABLE IF NOT EXISTS `flow_purchasing` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `provider` varchar(150) NOT NULL,
  `money` decimal(12,2) NOT NULL,
  `purchasedby` char(30) NOT NULL,
  `purchaseddate` datetime NOT NULL,
  `status` char(30) NOT NULL DEFAULT 'wait',
  `desc` text NOT NULL,
  `parent` mediumint(8) unsigned NOT NULL,
  `createdBy` varchar(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  `editedBy` varchar(30) NOT NULL,
  `editedDate` datetime NOT NULL,
  `mailto` text NOT NULL,
  `deleted` enum('0','1') NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP TABLE IF EXISTS `flow_stamp`;
CREATE TABLE IF NOT EXISTS `flow_stamp` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `proposer` varchar(200) NOT NULL,
  `reason` varchar(200) NOT NULL,
  `begin` datetime NOT NULL,
  `end` datetime NOT NULL,
  `type` varchar(200) NOT NULL,
  `desc` varchar(200) NOT NULL,
  `status` varchar(200) NOT NULL DEFAULT 'wait',
  `reviewedBy` varchar(200) NOT NULL,
  `reviewedDate` datetime NOT NULL,
  `parent` mediumint(8) unsigned NOT NULL,
  `createdBy` varchar(30) NOT NULL,
  `createdDate` datetime NOT NULL,
  `editedBy` varchar(30) NOT NULL,
  `editedDate` datetime NOT NULL,
  `mailto` text NOT NULL,
  `deleted` enum('0','1') NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- DROP VIEW IF EXISTS `view_datasource_7`;
CREATE VIEW `view_datasource_7` AS select id,name from `flow_meetingroom` where deleted = '0';

REPLACE INTO `sys_grouppriv` VALUES
(1,'buy','18'),
(1,'buy','19'),
(1,'buy','20'),
(1,'buy','batchcreate'),
(1,'buy','batchedit'),
(1,'buy','browse'),
(1,'buy','create'),
(1,'buy','delete'),
(1,'buy','edit'),
(1,'buy','export'),
(1,'buy','exporttemplate'),
(1,'buy','import'),
(1,'buy','link'),
(1,'buy','pay'),
(1,'buy','search'),
(1,'buy','showimport'),
(1,'buy','unlink'),
(1,'buy','view'),
(1,'car','8'),
(1,'car','batchcreate'),
(1,'car','batchedit'),
(1,'car','browse'),
(1,'car','create'),
(1,'car','delete'),
(1,'car','edit'),
(1,'car','export'),
(1,'car','exporttemplate'),
(1,'car','import'),
(1,'car','link'),
(1,'car','search'),
(1,'car','showimport'),
(1,'car','unlink'),
(1,'car','view'),
(1,'carbooking','12'),
(1,'carbooking','13'),
(1,'carbooking','9'),
(1,'carbooking','batchcreate'),
(1,'carbooking','batchedit'),
(1,'carbooking','browse'),
(1,'carbooking','create'),
(1,'carbooking','delete'),
(1,'carbooking','edit'),
(1,'carbooking','export'),
(1,'carbooking','exporttemplate'),
(1,'carbooking','import'),
(1,'carbooking','link'),
(1,'carbooking','pass'),
(1,'carbooking','reject'),
(1,'carbooking','search'),
(1,'carbooking','showimport'),
(1,'carbooking','unlink'),
(1,'carbooking','view'),
(1,'collect','14'),
(1,'collect','15'),
(1,'collect','16'),
(1,'collect','17'),
(1,'collect','batchcreate'),
(1,'collect','batchedit'),
(1,'collect','browse'),
(1,'collect','create'),
(1,'collect','delete'),
(1,'collect','edit'),
(1,'collect','export'),
(1,'collect','exporttemplate'),
(1,'collect','import'),
(1,'collect','link'),
(1,'collect','pass'),
(1,'collect','pay'),
(1,'collect','reject'),
(1,'collect','search'),
(1,'collect','showimport'),
(1,'collect','unlink'),
(1,'collect','view'),
(1,'meetingroom','1'),
(1,'meetingroom','3'),
(1,'meetingroom','4'),
(1,'meetingroom','5'),
(1,'meetingroom','batchcreate'),
(1,'meetingroom','batchedit'),
(1,'meetingroom','browse'),
(1,'meetingroom','create'),
(1,'meetingroom','delete'),
(1,'meetingroom','edit'),
(1,'meetingroom','export'),
(1,'meetingroom','exporttemplate'),
(1,'meetingroom','import'),
(1,'meetingroom','link'),
(1,'meetingroom','search'),
(1,'meetingroom','showimport'),
(1,'meetingroom','unlink'),
(1,'meetingroom','view'),
(1,'meetingroombooking','2'),
(1,'meetingroombooking','6'),
(1,'meetingroombooking','batchcreate'),
(1,'meetingroombooking','batchedit'),
(1,'meetingroombooking','browse'),
(1,'meetingroombooking','create'),
(1,'meetingroombooking','delete'),
(1,'meetingroombooking','edit'),
(1,'meetingroombooking','export'),
(1,'meetingroombooking','exporttemplate'),
(1,'meetingroombooking','import'),
(1,'meetingroombooking','link'),
(1,'meetingroombooking','search'),
(1,'meetingroombooking','showimport'),
(1,'meetingroombooking','unlink'),
(1,'meetingroombooking','view'),
(1,'purchasing','21'),
(1,'purchasing','batchcreate'),
(1,'purchasing','batchedit'),
(1,'purchasing','browse'),
(1,'purchasing','create'),
(1,'purchasing','delete'),
(1,'purchasing','edit'),
(1,'purchasing','export'),
(1,'purchasing','exporttemplate'),
(1,'purchasing','import'),
(1,'purchasing','link'),
(1,'purchasing','pass'),
(1,'purchasing','reject'),
(1,'purchasing','search'),
(1,'purchasing','showimport'),
(1,'purchasing','unlink'),
(1,'purchasing','view'),
(1,'stamp','10'),
(1,'stamp','11'),
(1,'stamp','7'),
(1,'stamp','batchcreate'),
(1,'stamp','batchedit'),
(1,'stamp','browse'),
(1,'stamp','create'),
(1,'stamp','delete'),
(1,'stamp','edit'),
(1,'stamp','export'),
(1,'stamp','exporttemplate'),
(1,'stamp','import'),
(1,'stamp','link'),
(1,'stamp','pass'),
(1,'stamp','reject'),
(1,'stamp','revoke'),
(1,'stamp','search'),
(1,'stamp','showimport'),
(1,'stamp','submit'),
(1,'stamp','unlink'),
(1,'stamp','view');
